/********************************************************************************
** Form generated from reading UI file 'job_settings_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef JOB_SETTINGS_DIALOG_H
#define JOB_SETTINGS_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QVBoxLayout>
#include "mkvtoolnix-gui/info/job_settings_widget.h"

namespace mtx {
namespace gui {
namespace Info {

class Ui_JobSettingsDialog
{
public:
    QVBoxLayout *verticalLayout;
    mtx::gui::Info::JobSettingsWidget *settings;
    QFrame *line;
    QCheckBox *saveAsDefault;
    QDialogButtonBox *buttons;

    void setupUi(QDialog *mtx__gui__Info__JobSettingsDialog)
    {
        if (mtx__gui__Info__JobSettingsDialog->objectName().isEmpty())
            mtx__gui__Info__JobSettingsDialog->setObjectName("mtx__gui__Info__JobSettingsDialog");
        mtx__gui__Info__JobSettingsDialog->resize(271, 134);
        verticalLayout = new QVBoxLayout(mtx__gui__Info__JobSettingsDialog);
        verticalLayout->setObjectName("verticalLayout");
        settings = new mtx::gui::Info::JobSettingsWidget(mtx__gui__Info__JobSettingsDialog);
        settings->setObjectName("settings");

        verticalLayout->addWidget(settings);

        line = new QFrame(mtx__gui__Info__JobSettingsDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        saveAsDefault = new QCheckBox(mtx__gui__Info__JobSettingsDialog);
        saveAsDefault->setObjectName("saveAsDefault");

        verticalLayout->addWidget(saveAsDefault);

        buttons = new QDialogButtonBox(mtx__gui__Info__JobSettingsDialog);
        buttons->setObjectName("buttons");
        buttons->setOrientation(Qt::Horizontal);
        buttons->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttons);


        retranslateUi(mtx__gui__Info__JobSettingsDialog);

        QMetaObject::connectSlotsByName(mtx__gui__Info__JobSettingsDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__Info__JobSettingsDialog)
    {
        mtx__gui__Info__JobSettingsDialog->setWindowTitle(QTR("Settings for saving output to a text file", nullptr));
        saveAsDefault->setText(QTR("Save as &default for saving output to text files", nullptr));
    } // retranslateUi

};

} // namespace Info
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Info {
namespace Ui {
    class JobSettingsDialog: public Ui_JobSettingsDialog {};
} // namespace Ui
} // namespace Info
} // namespace gui
} // namespace mtx

#endif // JOB_SETTINGS_DIALOG_H
