/********************************************************************************
** Form generated from reading UI file 'side_by_side_multi_select.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef SIDE_BY_SIDE_MULTI_SELECT_H
#define SIDE_BY_SIDE_MULTI_SELECT_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

namespace mtx {
namespace gui {
namespace Util {

class Ui_SideBySideMultiSelect
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *availableLabel;
    QLabel *selectedLabel;
    QListWidget *available;
    QVBoxLayout *verticalLayout_10;
    QSpacerItem *verticalSpacer_5;
    QPushButton *moveToSelectedButton;
    QPushButton *moveToAvailableButton;
    QSpacerItem *verticalSpacer;
    QPushButton *revertButton;
    QSpacerItem *verticalSpacer_6;
    QListWidget *selected;

    void setupUi(QWidget *mtx__gui__Util__SideBySideMultiSelect)
    {
        if (mtx__gui__Util__SideBySideMultiSelect->objectName().isEmpty())
            mtx__gui__Util__SideBySideMultiSelect->setObjectName("mtx__gui__Util__SideBySideMultiSelect");
        mtx__gui__Util__SideBySideMultiSelect->resize(858, 548);
        mtx__gui__Util__SideBySideMultiSelect->setWindowTitle(QString::fromUtf8("SideBySideMultiSelect"));
        verticalLayout = new QVBoxLayout(mtx__gui__Util__SideBySideMultiSelect);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        availableLabel = new QLabel(mtx__gui__Util__SideBySideMultiSelect);
        availableLabel->setObjectName("availableLabel");

        gridLayout->addWidget(availableLabel, 0, 0, 1, 1);

        selectedLabel = new QLabel(mtx__gui__Util__SideBySideMultiSelect);
        selectedLabel->setObjectName("selectedLabel");

        gridLayout->addWidget(selectedLabel, 0, 2, 1, 1);

        available = new QListWidget(mtx__gui__Util__SideBySideMultiSelect);
        available->setObjectName("available");
        available->setMinimumSize(QSize(0, 90));
        available->setEditTriggers(QAbstractItemView::NoEditTriggers);
        available->setSelectionMode(QAbstractItemView::ExtendedSelection);
        available->setSortingEnabled(true);

        gridLayout->addWidget(available, 1, 0, 1, 1);

        verticalLayout_10 = new QVBoxLayout();
        verticalLayout_10->setObjectName("verticalLayout_10");
        verticalSpacer_5 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_10->addItem(verticalSpacer_5);

        moveToSelectedButton = new QPushButton(mtx__gui__Util__SideBySideMultiSelect);
        moveToSelectedButton->setObjectName("moveToSelectedButton");
        moveToSelectedButton->setMinimumSize(QSize(24, 24));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("arrow-right")));
        moveToSelectedButton->setIcon(icon);

        verticalLayout_10->addWidget(moveToSelectedButton);

        moveToAvailableButton = new QPushButton(mtx__gui__Util__SideBySideMultiSelect);
        moveToAvailableButton->setObjectName("moveToAvailableButton");
        moveToAvailableButton->setMinimumSize(QSize(24, 24));
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("arrow-left")));
        moveToAvailableButton->setIcon(icon1);

        verticalLayout_10->addWidget(moveToAvailableButton);

        verticalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);

        verticalLayout_10->addItem(verticalSpacer);

        revertButton = new QPushButton(mtx__gui__Util__SideBySideMultiSelect);
        revertButton->setObjectName("revertButton");
        revertButton->setMinimumSize(QSize(24, 24));
        revertButton->setText(QString::fromUtf8(""));
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("edit-undo")));
        revertButton->setIcon(icon2);

        verticalLayout_10->addWidget(revertButton);

        verticalSpacer_6 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_10->addItem(verticalSpacer_6);


        gridLayout->addLayout(verticalLayout_10, 1, 1, 1, 1);

        selected = new QListWidget(mtx__gui__Util__SideBySideMultiSelect);
        selected->setObjectName("selected");
        selected->setMinimumSize(QSize(0, 90));
        selected->setSelectionMode(QAbstractItemView::ExtendedSelection);
        selected->setSortingEnabled(true);

        gridLayout->addWidget(selected, 1, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);


        retranslateUi(mtx__gui__Util__SideBySideMultiSelect);

        QMetaObject::connectSlotsByName(mtx__gui__Util__SideBySideMultiSelect);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__Util__SideBySideMultiSelect)
    {
        availableLabel->setText(QTR("Available:", nullptr));
        selectedLabel->setText(QTR("Selected:", nullptr));
        moveToSelectedButton->setText(QString());
        moveToAvailableButton->setText(QString());
        (void)mtx__gui__Util__SideBySideMultiSelect;
    } // retranslateUi

};

} // namespace Util
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Util {
namespace Ui {
    class SideBySideMultiSelect: public Ui_SideBySideMultiSelect {};
} // namespace Ui
} // namespace Util
} // namespace gui
} // namespace mtx

#endif // SIDE_BY_SIDE_MULTI_SELECT_H
