/********************************************************************************
** Form generated from reading UI file 'executable_location_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef EXECUTABLE_LOCATION_DIALOG_H
#define EXECUTABLE_LOCATION_DIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

namespace mtx {
namespace gui {
namespace Merge {

class Ui_ExecutableLocationDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *lTitle;
    QFrame *line;
    QLabel *lText;
    QLabel *lURL;
    QHBoxLayout *horizontalLayout;
    QLineEdit *leExecutable;
    QPushButton *pbBrowse;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *mtx__gui__Merge__ExecutableLocationDialog)
    {
        if (mtx__gui__Merge__ExecutableLocationDialog->objectName().isEmpty())
            mtx__gui__Merge__ExecutableLocationDialog->setObjectName("mtx__gui__Merge__ExecutableLocationDialog");
        mtx__gui__Merge__ExecutableLocationDialog->resize(403, 191);
        mtx__gui__Merge__ExecutableLocationDialog->setWindowTitle(QString::fromUtf8("Dialog"));
        verticalLayout = new QVBoxLayout(mtx__gui__Merge__ExecutableLocationDialog);
        verticalLayout->setObjectName("verticalLayout");
        lTitle = new QLabel(mtx__gui__Merge__ExecutableLocationDialog);
        lTitle->setObjectName("lTitle");
        lTitle->setText(QString::fromUtf8("xyz not found"));

        verticalLayout->addWidget(lTitle);

        line = new QFrame(mtx__gui__Merge__ExecutableLocationDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        lText = new QLabel(mtx__gui__Merge__ExecutableLocationDialog);
        lText->setObjectName("lText");
        lText->setText(QString::fromUtf8("TextLabel"));
        lText->setWordWrap(true);

        verticalLayout->addWidget(lText);

        lURL = new QLabel(mtx__gui__Merge__ExecutableLocationDialog);
        lURL->setObjectName("lURL");
        lURL->setText(QString::fromUtf8("TextLabel"));
        lURL->setWordWrap(true);
        lURL->setOpenExternalLinks(true);

        verticalLayout->addWidget(lURL);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        leExecutable = new QLineEdit(mtx__gui__Merge__ExecutableLocationDialog);
        leExecutable->setObjectName("leExecutable");
        leExecutable->setClearButtonEnabled(true);

        horizontalLayout->addWidget(leExecutable);

        pbBrowse = new QPushButton(mtx__gui__Merge__ExecutableLocationDialog);
        pbBrowse->setObjectName("pbBrowse");
        pbBrowse->setText(QString::fromUtf8(""));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-open")));
        pbBrowse->setIcon(icon);

        horizontalLayout->addWidget(pbBrowse);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(mtx__gui__Merge__ExecutableLocationDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(mtx__gui__Merge__ExecutableLocationDialog);

        QMetaObject::connectSlotsByName(mtx__gui__Merge__ExecutableLocationDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__Merge__ExecutableLocationDialog)
    {
        (void)mtx__gui__Merge__ExecutableLocationDialog;
    } // retranslateUi

};

} // namespace Merge
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Merge {
namespace Ui {
    class ExecutableLocationDialog: public Ui_ExecutableLocationDialog {};
} // namespace Ui
} // namespace Merge
} // namespace gui
} // namespace mtx

#endif // EXECUTABLE_LOCATION_DIALOG_H
