/********************************************************************************
** Form generated from reading UI file 'element_viewer_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef ELEMENT_VIEWER_DIALOG_H
#define ELEMENT_VIEWER_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>

namespace mtx {
namespace gui {
namespace Info {

class Ui_ElementViewerDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout_2;
    QLabel *contentLabel;
    QLabel *informationLabel;
    QFrame *line;
    QFrame *line_2;
    QTextBrowser *content;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *nameLabel;
    QLabel *name;
    QLabel *positionLabel;
    QLabel *sizeLabel;
    QLabel *position;
    QLabel *size;
    QLabel *adler32Label;
    QLabel *adler32;
    QLabel *legendLabel;
    QTextBrowser *legend;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QLabel *limitedBytesShownLabel;
    QSpacerItem *horizontalSpacer;
    QPushButton *detachWindowButton;
    QPushButton *closeButton;

    void setupUi(QDialog *mtx__gui__Info__ElementViewerDialog)
    {
        if (mtx__gui__Info__ElementViewerDialog->objectName().isEmpty())
            mtx__gui__Info__ElementViewerDialog->setObjectName("mtx__gui__Info__ElementViewerDialog");
        mtx__gui__Info__ElementViewerDialog->resize(881, 550);
        mtx__gui__Info__ElementViewerDialog->setMinimumSize(QSize(0, 550));
        mtx__gui__Info__ElementViewerDialog->setWindowTitle(QString::fromUtf8("Element viewer"));
        verticalLayout_2 = new QVBoxLayout(mtx__gui__Info__ElementViewerDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        contentLabel = new QLabel(mtx__gui__Info__ElementViewerDialog);
        contentLabel->setObjectName("contentLabel");

        gridLayout_2->addWidget(contentLabel, 0, 0, 1, 1);

        informationLabel = new QLabel(mtx__gui__Info__ElementViewerDialog);
        informationLabel->setObjectName("informationLabel");

        gridLayout_2->addWidget(informationLabel, 0, 1, 1, 1);

        line = new QFrame(mtx__gui__Info__ElementViewerDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_2->addWidget(line, 1, 0, 1, 1);

        line_2 = new QFrame(mtx__gui__Info__ElementViewerDialog);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_2->addWidget(line_2, 1, 1, 1, 1);

        content = new QTextBrowser(mtx__gui__Info__ElementViewerDialog);
        content->setObjectName("content");
        content->setMinimumSize(QSize(500, 0));
        content->setLineWrapMode(QTextEdit::NoWrap);
        content->setHtml(QString::fromUtf8("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Noto Sans'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:'DejaVu Sans';\"><br /></p></body></html>"));

        gridLayout_2->addWidget(content, 2, 0, 1, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        nameLabel = new QLabel(mtx__gui__Info__ElementViewerDialog);
        nameLabel->setObjectName("nameLabel");

        gridLayout->addWidget(nameLabel, 0, 0, 1, 1);

        name = new QLabel(mtx__gui__Info__ElementViewerDialog);
        name->setObjectName("name");
        name->setText(QString::fromUtf8("TheName"));

        gridLayout->addWidget(name, 0, 1, 1, 1);

        positionLabel = new QLabel(mtx__gui__Info__ElementViewerDialog);
        positionLabel->setObjectName("positionLabel");

        gridLayout->addWidget(positionLabel, 1, 0, 1, 1);

        sizeLabel = new QLabel(mtx__gui__Info__ElementViewerDialog);
        sizeLabel->setObjectName("sizeLabel");

        gridLayout->addWidget(sizeLabel, 2, 0, 1, 1);

        position = new QLabel(mtx__gui__Info__ElementViewerDialog);
        position->setObjectName("position");
        position->setText(QString::fromUtf8("ThePosition"));

        gridLayout->addWidget(position, 1, 1, 1, 1);

        size = new QLabel(mtx__gui__Info__ElementViewerDialog);
        size->setObjectName("size");
        size->setText(QString::fromUtf8("TheSize"));

        gridLayout->addWidget(size, 2, 1, 1, 1);

        adler32Label = new QLabel(mtx__gui__Info__ElementViewerDialog);
        adler32Label->setObjectName("adler32Label");

        gridLayout->addWidget(adler32Label, 3, 0, 1, 1);

        adler32 = new QLabel(mtx__gui__Info__ElementViewerDialog);
        adler32->setObjectName("adler32");
        adler32->setText(QString::fromUtf8("TheChecksum"));

        gridLayout->addWidget(adler32, 3, 1, 1, 1);

        gridLayout->setColumnStretch(1, 1);

        verticalLayout->addLayout(gridLayout);

        legendLabel = new QLabel(mtx__gui__Info__ElementViewerDialog);
        legendLabel->setObjectName("legendLabel");

        verticalLayout->addWidget(legendLabel);

        legend = new QTextBrowser(mtx__gui__Info__ElementViewerDialog);
        legend->setObjectName("legend");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(legend->sizePolicy().hasHeightForWidth());
        legend->setSizePolicy(sizePolicy);
        legend->setFrameShape(QFrame::NoFrame);

        verticalLayout->addWidget(legend);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        verticalLayout->addItem(verticalSpacer);

        verticalLayout->setStretch(2, 1);

        gridLayout_2->addLayout(verticalLayout, 2, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        limitedBytesShownLabel = new QLabel(mtx__gui__Info__ElementViewerDialog);
        limitedBytesShownLabel->setObjectName("limitedBytesShownLabel");
        limitedBytesShownLabel->setText(QString::fromUtf8("TheNoteThatNotAllIsShown"));

        horizontalLayout->addWidget(limitedBytesShownLabel);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        detachWindowButton = new QPushButton(mtx__gui__Info__ElementViewerDialog);
        detachWindowButton->setObjectName("detachWindowButton");
        detachWindowButton->setAutoDefault(false);

        horizontalLayout->addWidget(detachWindowButton);

        closeButton = new QPushButton(mtx__gui__Info__ElementViewerDialog);
        closeButton->setObjectName("closeButton");

        horizontalLayout->addWidget(closeButton);


        verticalLayout_2->addLayout(horizontalLayout);


        retranslateUi(mtx__gui__Info__ElementViewerDialog);

        closeButton->setDefault(true);


        QMetaObject::connectSlotsByName(mtx__gui__Info__ElementViewerDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__Info__ElementViewerDialog)
    {
        contentLabel->setText(QTR("Content", nullptr));
        informationLabel->setText(QTR("Information", nullptr));
        nameLabel->setText(QTR("Name:", nullptr));
        positionLabel->setText(QTR("Position:", nullptr));
        sizeLabel->setText(QTR("Size:", nullptr));
        adler32Label->setText(QTR("Adler-32:", nullptr));
        legendLabel->setText(QTR("Legend:", nullptr));
        detachWindowButton->setText(QTR("&Detach window", nullptr));
        closeButton->setText(QTR("&Close window", nullptr));
        (void)mtx__gui__Info__ElementViewerDialog;
    } // retranslateUi

};

} // namespace Info
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Info {
namespace Ui {
    class ElementViewerDialog: public Ui_ElementViewerDialog {};
} // namespace Ui
} // namespace Info
} // namespace gui
} // namespace mtx

#endif // ELEMENT_VIEWER_DIALOG_H
