/********************************************************************************
** Form generated from reading UI file 'renumber_sub_chapters_parameters_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef RENUMBER_SUB_CHAPTERS_PARAMETERS_DIALOG_H
#define RENUMBER_SUB_CHAPTERS_PARAMETERS_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "mkvtoolnix-gui/util/basic_spin_box.h"
#include "mkvtoolnix-gui/util/language_display_widget.h"

namespace mtx {
namespace gui {
namespace ChapterEditor {

class Ui_RenumberSubChaptersParametersDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QFrame *line;
    QGridLayout *gridLayout;
    QLabel *label_3;
    mtx::gui::Util::BasicSpinBox *sbNumberOfEntries;
    QLabel *label_4;
    mtx::gui::Util::BasicSpinBox *sbFirstChapterNumber;
    QLineEdit *leNameTemplate;
    mtx::gui::Util::LanguageDisplayWidget *ldwLanguageOfNamesToReplace;
    QLabel *label_2;
    QComboBox *cbFirstEntryToRenumber;
    QLabel *label_5;
    QComboBox *cbLanguageOfNamesMode;
    QLabel *label_7;
    QCheckBox *cbSkipHidden;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog)
    {
        if (mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog->objectName().isEmpty())
            mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog->setObjectName("mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog");
        mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog->resize(536, 334);
        verticalLayout = new QVBoxLayout(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        line = new QFrame(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_3 = new QLabel(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        sbNumberOfEntries = new mtx::gui::Util::BasicSpinBox(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
        sbNumberOfEntries->setObjectName("sbNumberOfEntries");
        sbNumberOfEntries->setValue(0);

        gridLayout->addWidget(sbNumberOfEntries, 1, 1, 1, 1);

        label_4 = new QLabel(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 1, 0, 1, 1);

        sbFirstChapterNumber = new mtx::gui::Util::BasicSpinBox(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
        sbFirstChapterNumber->setObjectName("sbFirstChapterNumber");
        sbFirstChapterNumber->setMinimum(1);
        sbFirstChapterNumber->setMaximum(999999);

        gridLayout->addWidget(sbFirstChapterNumber, 2, 1, 1, 1);

        leNameTemplate = new QLineEdit(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
        leNameTemplate->setObjectName("leNameTemplate");
        leNameTemplate->setClearButtonEnabled(true);

        gridLayout->addWidget(leNameTemplate, 3, 1, 1, 1);

        ldwLanguageOfNamesToReplace = new mtx::gui::Util::LanguageDisplayWidget(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
        ldwLanguageOfNamesToReplace->setObjectName("ldwLanguageOfNamesToReplace");
        ldwLanguageOfNamesToReplace->setMinimumSize(QSize(0, 32));

        gridLayout->addWidget(ldwLanguageOfNamesToReplace, 5, 1, 1, 1);

        label_2 = new QLabel(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 3, 0, 1, 1);

        cbFirstEntryToRenumber = new QComboBox(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
        cbFirstEntryToRenumber->setObjectName("cbFirstEntryToRenumber");

        gridLayout->addWidget(cbFirstEntryToRenumber, 0, 1, 1, 1);

        label_5 = new QLabel(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 2, 0, 1, 1);

        cbLanguageOfNamesMode = new QComboBox(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
        cbLanguageOfNamesMode->setObjectName("cbLanguageOfNamesMode");

        gridLayout->addWidget(cbLanguageOfNamesMode, 4, 1, 1, 1);

        label_7 = new QLabel(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
        label_7->setObjectName("label_7");

        gridLayout->addWidget(label_7, 4, 0, 1, 1);


        verticalLayout->addLayout(gridLayout);

        cbSkipHidden = new QCheckBox(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
        cbSkipHidden->setObjectName("cbSkipHidden");
        cbSkipHidden->setChecked(true);

        verticalLayout->addWidget(cbSkipHidden);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label_3->setBuddy(cbFirstEntryToRenumber);
        label_4->setBuddy(sbNumberOfEntries);
        label_2->setBuddy(leNameTemplate);
        label_5->setBuddy(sbFirstChapterNumber);
        label_7->setBuddy(cbLanguageOfNamesMode);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(cbFirstEntryToRenumber, sbNumberOfEntries);
        QWidget::setTabOrder(sbNumberOfEntries, sbFirstChapterNumber);
        QWidget::setTabOrder(sbFirstChapterNumber, leNameTemplate);
        QWidget::setTabOrder(leNameTemplate, cbLanguageOfNamesMode);
        QWidget::setTabOrder(cbLanguageOfNamesMode, cbSkipHidden);

        retranslateUi(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);

        QMetaObject::connectSlotsByName(mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog)
    {
        mtx__gui__ChapterEditor__RenumberSubChaptersParametersDialog->setWindowTitle(QTR("Renumbering sub-chapters", nullptr));
        label->setText(QTR("Renumbering existing sub-chapters", nullptr));
        label_3->setText(QTR("&First entry to renumber:", nullptr));
        sbNumberOfEntries->setSpecialValueText(QTR("All entries", nullptr));
        sbNumberOfEntries->setSuffix(QString());
        label_4->setText(QTR("&Number of entries to renumber:", nullptr));
        label_2->setText(QTR("Na&me template:", nullptr));
        label_5->setText(QTR("&Chapter number of first created entry:", nullptr));
        label_7->setText(QTR("&Language of chapter names to replace:", nullptr));
        cbSkipHidden->setText(QTR("&Skip chapters flagged \"hidden\"", nullptr));
    } // retranslateUi

};

} // namespace ChapterEditor
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace ChapterEditor {
namespace Ui {
    class RenumberSubChaptersParametersDialog: public Ui_RenumberSubChaptersParametersDialog {};
} // namespace Ui
} // namespace ChapterEditor
} // namespace gui
} // namespace mtx

#endif // RENUMBER_SUB_CHAPTERS_PARAMETERS_DIALOG_H
