/********************************************************************************
** Form generated from reading UI file 'adding_directories_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef ADDING_DIRECTORIES_DIALOG_H
#define ADDING_DIRECTORIES_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

namespace mtx {
namespace gui {
namespace Merge {

class Ui_AddingDirectoriesDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *lTitle;
    QFrame *line;
    QLabel *lQuestion;
    QLabel *lOptions;
    QRadioButton *rbFlat;
    QRadioButton *rbAddEachDirectoryToNew;
    QFrame *line_2;
    QCheckBox *cbAlwaysUseThisDecision;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *mtx__gui__Merge__AddingDirectoriesDialog)
    {
        if (mtx__gui__Merge__AddingDirectoriesDialog->objectName().isEmpty())
            mtx__gui__Merge__AddingDirectoriesDialog->setObjectName("mtx__gui__Merge__AddingDirectoriesDialog");
        mtx__gui__Merge__AddingDirectoriesDialog->resize(691, 232);
        verticalLayout = new QVBoxLayout(mtx__gui__Merge__AddingDirectoriesDialog);
        verticalLayout->setObjectName("verticalLayout");
        lTitle = new QLabel(mtx__gui__Merge__AddingDirectoriesDialog);
        lTitle->setObjectName("lTitle");
        lTitle->setMinimumSize(QSize(600, 0));
        lTitle->setWordWrap(true);

        verticalLayout->addWidget(lTitle);

        line = new QFrame(mtx__gui__Merge__AddingDirectoriesDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        lQuestion = new QLabel(mtx__gui__Merge__AddingDirectoriesDialog);
        lQuestion->setObjectName("lQuestion");
        lQuestion->setWordWrap(true);

        verticalLayout->addWidget(lQuestion);

        lOptions = new QLabel(mtx__gui__Merge__AddingDirectoriesDialog);
        lOptions->setObjectName("lOptions");
        lOptions->setText(QString::fromUtf8("text"));
        lOptions->setTextFormat(Qt::RichText);
        lOptions->setWordWrap(true);

        verticalLayout->addWidget(lOptions);

        rbFlat = new QRadioButton(mtx__gui__Merge__AddingDirectoriesDialog);
        rbFlat->setObjectName("rbFlat");

        verticalLayout->addWidget(rbFlat);

        rbAddEachDirectoryToNew = new QRadioButton(mtx__gui__Merge__AddingDirectoriesDialog);
        rbAddEachDirectoryToNew->setObjectName("rbAddEachDirectoryToNew");

        verticalLayout->addWidget(rbAddEachDirectoryToNew);

        line_2 = new QFrame(mtx__gui__Merge__AddingDirectoriesDialog);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line_2);

        cbAlwaysUseThisDecision = new QCheckBox(mtx__gui__Merge__AddingDirectoriesDialog);
        cbAlwaysUseThisDecision->setObjectName("cbAlwaysUseThisDecision");

        verticalLayout->addWidget(cbAlwaysUseThisDecision);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        buttonBox = new QDialogButtonBox(mtx__gui__Merge__AddingDirectoriesDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout);

        QWidget::setTabOrder(rbFlat, rbAddEachDirectoryToNew);
        QWidget::setTabOrder(rbAddEachDirectoryToNew, cbAlwaysUseThisDecision);

        retranslateUi(mtx__gui__Merge__AddingDirectoriesDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, mtx__gui__Merge__AddingDirectoriesDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, mtx__gui__Merge__AddingDirectoriesDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(mtx__gui__Merge__AddingDirectoriesDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__Merge__AddingDirectoriesDialog)
    {
        mtx__gui__Merge__AddingDirectoriesDialog->setWindowTitle(QTR("Adding directories via drag & drop or copy & paste", nullptr));
        lTitle->setText(QTR("Adding directories via drag & drop or copy & paste", nullptr));
        lQuestion->setText(QTR("You've dragged & dropped or copied & pasted at least one directory. There are several ways to handle them:", nullptr));
        rbFlat->setText(QTR("&Handle all files from all directories as a single list of files", nullptr));
        rbAddEachDirectoryToNew->setText(QTR("&Create a new multiplex settings tab for each directory", nullptr));
        cbAlwaysUseThisDecision->setText(QTR("Alwa&ys use the action selected above and don't ask again", nullptr));
    } // retranslateUi

};

} // namespace Merge
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Merge {
namespace Ui {
    class AddingDirectoriesDialog: public Ui_AddingDirectoriesDialog {};
} // namespace Ui
} // namespace Merge
} // namespace gui
} // namespace mtx

#endif // ADDING_DIRECTORIES_DIALOG_H
