/********************************************************************************
** Form generated from reading UI file 'tab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef TAB_H
#define TAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/util/basic_tree_view.h"
#include "mkvtoolnix-gui/util/elide_label.h"

namespace mtx {
namespace gui {
namespace HeaderEditor {

class Ui_Tab
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *fileNameLabel;
    mtx::gui::Util::ElideLabel *fileName;
    QLabel *directoryLabel;
    mtx::gui::Util::ElideLabel *directory;
    QFrame *line;
    QSplitter *headerEditorSplitter;
    mtx::gui::Util::BasicTreeView *elements;
    QStackedWidget *pageContainer;
    QWidget *emptyPage;

    void setupUi(QWidget *mtx__gui__HeaderEditor__Tab)
    {
        if (mtx__gui__HeaderEditor__Tab->objectName().isEmpty())
            mtx__gui__HeaderEditor__Tab->setObjectName("mtx__gui__HeaderEditor__Tab");
        mtx__gui__HeaderEditor__Tab->resize(735, 427);
        mtx__gui__HeaderEditor__Tab->setWindowTitle(QString::fromUtf8("Form"));
        verticalLayout = new QVBoxLayout(mtx__gui__HeaderEditor__Tab);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        fileNameLabel = new QLabel(mtx__gui__HeaderEditor__Tab);
        fileNameLabel->setObjectName("fileNameLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(fileNameLabel->sizePolicy().hasHeightForWidth());
        fileNameLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(fileNameLabel, 0, 0, 1, 1);

        fileName = new mtx::gui::Util::ElideLabel(mtx__gui__HeaderEditor__Tab);
        fileName->setObjectName("fileName");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(fileName->sizePolicy().hasHeightForWidth());
        fileName->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(fileName, 0, 1, 1, 1);

        directoryLabel = new QLabel(mtx__gui__HeaderEditor__Tab);
        directoryLabel->setObjectName("directoryLabel");
        sizePolicy.setHeightForWidth(directoryLabel->sizePolicy().hasHeightForWidth());
        directoryLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(directoryLabel, 1, 0, 1, 1);

        directory = new mtx::gui::Util::ElideLabel(mtx__gui__HeaderEditor__Tab);
        directory->setObjectName("directory");
        sizePolicy1.setHeightForWidth(directory->sizePolicy().hasHeightForWidth());
        directory->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(directory, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        line = new QFrame(mtx__gui__HeaderEditor__Tab);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        headerEditorSplitter = new QSplitter(mtx__gui__HeaderEditor__Tab);
        headerEditorSplitter->setObjectName("headerEditorSplitter");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(headerEditorSplitter->sizePolicy().hasHeightForWidth());
        headerEditorSplitter->setSizePolicy(sizePolicy2);
        headerEditorSplitter->setOrientation(Qt::Horizontal);
        headerEditorSplitter->setChildrenCollapsible(false);
        elements = new mtx::gui::Util::BasicTreeView(headerEditorSplitter);
        elements->setObjectName("elements");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(elements->sizePolicy().hasHeightForWidth());
        elements->setSizePolicy(sizePolicy3);
        elements->setMinimumSize(QSize(70, 0));
        elements->setContextMenuPolicy(Qt::CustomContextMenu);
        elements->setAcceptDrops(true);
        elements->setEditTriggers(QAbstractItemView::NoEditTriggers);
        elements->setDragEnabled(true);
        elements->setDragDropMode(QAbstractItemView::InternalMove);
        headerEditorSplitter->addWidget(elements);
        pageContainer = new QStackedWidget(headerEditorSplitter);
        pageContainer->setObjectName("pageContainer");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy4.setHorizontalStretch(1);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(pageContainer->sizePolicy().hasHeightForWidth());
        pageContainer->setSizePolicy(sizePolicy4);
        pageContainer->setMinimumSize(QSize(370, 0));
        emptyPage = new QWidget();
        emptyPage->setObjectName("emptyPage");
        pageContainer->addWidget(emptyPage);
        headerEditorSplitter->addWidget(pageContainer);

        verticalLayout->addWidget(headerEditorSplitter);


        retranslateUi(mtx__gui__HeaderEditor__Tab);

        QMetaObject::connectSlotsByName(mtx__gui__HeaderEditor__Tab);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__HeaderEditor__Tab)
    {
        fileNameLabel->setText(QTR("File name:", nullptr));
        directoryLabel->setText(QTR("Directory:", nullptr));
        (void)mtx__gui__HeaderEditor__Tab;
    } // retranslateUi

};

} // namespace HeaderEditor
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace HeaderEditor {
namespace Ui {
    class Tab: public Ui_Tab {};
} // namespace Ui
} // namespace HeaderEditor
} // namespace gui
} // namespace mtx

#endif // TAB_H
