/********************************************************************************
** Form generated from reading UI file 'action_for_dropped_files_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef ACTION_FOR_DROPPED_FILES_DIALOG_H
#define ACTION_FOR_DROPPED_FILES_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

namespace mtx {
namespace gui {
namespace HeaderEditor {

class Ui_ActionForDroppedFilesDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QFrame *line;
    QLabel *label_2;
    QRadioButton *rbOpen;
    QRadioButton *rbAddAttachments;
    QCheckBox *cbAlwaysUseThisDecision;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *mtx__gui__HeaderEditor__ActionForDroppedFilesDialog)
    {
        if (mtx__gui__HeaderEditor__ActionForDroppedFilesDialog->objectName().isEmpty())
            mtx__gui__HeaderEditor__ActionForDroppedFilesDialog->setObjectName("mtx__gui__HeaderEditor__ActionForDroppedFilesDialog");
        mtx__gui__HeaderEditor__ActionForDroppedFilesDialog->resize(573, 199);
        verticalLayout = new QVBoxLayout(mtx__gui__HeaderEditor__ActionForDroppedFilesDialog);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(mtx__gui__HeaderEditor__ActionForDroppedFilesDialog);
        label->setObjectName("label");
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        line = new QFrame(mtx__gui__HeaderEditor__ActionForDroppedFilesDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        label_2 = new QLabel(mtx__gui__HeaderEditor__ActionForDroppedFilesDialog);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        verticalLayout->addWidget(label_2);

        rbOpen = new QRadioButton(mtx__gui__HeaderEditor__ActionForDroppedFilesDialog);
        rbOpen->setObjectName("rbOpen");

        verticalLayout->addWidget(rbOpen);

        rbAddAttachments = new QRadioButton(mtx__gui__HeaderEditor__ActionForDroppedFilesDialog);
        rbAddAttachments->setObjectName("rbAddAttachments");

        verticalLayout->addWidget(rbAddAttachments);

        cbAlwaysUseThisDecision = new QCheckBox(mtx__gui__HeaderEditor__ActionForDroppedFilesDialog);
        cbAlwaysUseThisDecision->setObjectName("cbAlwaysUseThisDecision");

        verticalLayout->addWidget(cbAlwaysUseThisDecision);

        verticalSpacer = new QSpacerItem(20, 14, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        buttonBox = new QDialogButtonBox(mtx__gui__HeaderEditor__ActionForDroppedFilesDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout);

        QWidget::setTabOrder(rbOpen, rbAddAttachments);
        QWidget::setTabOrder(rbAddAttachments, cbAlwaysUseThisDecision);

        retranslateUi(mtx__gui__HeaderEditor__ActionForDroppedFilesDialog);

        QMetaObject::connectSlotsByName(mtx__gui__HeaderEditor__ActionForDroppedFilesDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__HeaderEditor__ActionForDroppedFilesDialog)
    {
        mtx__gui__HeaderEditor__ActionForDroppedFilesDialog->setWindowTitle(QTR("Opening files or adding as attachments", nullptr));
        label->setText(QTR("Opening files or adding as attachments", nullptr));
        label_2->setText(QTR("What do you want to do with the files you've dragged & dropped here?", nullptr));
        rbOpen->setText(QTR("&Open as new tabs in the header editor", nullptr));
        rbAddAttachments->setText(QTR("Add as new &attachments to the current file", nullptr));
        cbAlwaysUseThisDecision->setText(QTR("Alwa&ys use the action selected above and don't ask again", nullptr));
    } // retranslateUi

};

} // namespace HeaderEditor
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace HeaderEditor {
namespace Ui {
    class ActionForDroppedFilesDialog: public Ui_ActionForDroppedFilesDialog {};
} // namespace Ui
} // namespace HeaderEditor
} // namespace gui
} // namespace mtx

#endif // ACTION_FOR_DROPPED_FILES_DIALOG_H
