/********************************************************************************
** Form generated from reading UI file 'tab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef TAB_H
#define TAB_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/util/basic_line_edit.h"
#include "mkvtoolnix-gui/util/basic_tree_view.h"
#include "mkvtoolnix-gui/util/elide_label.h"
#include "mkvtoolnix-gui/util/language_display_widget.h"

namespace mtx {
namespace gui {
namespace ChapterEditor {

class Ui_Tab
{
public:
    QVBoxLayout *verticalLayout_5;
    QGridLayout *gridLayout;
    QLabel *fileNameLabel;
    mtx::gui::Util::ElideLabel *fileName;
    QLabel *directoryLabel;
    mtx::gui::Util::ElideLabel *directory;
    QFrame *line;
    QSplitter *chapterEditorSplitter;
    mtx::gui::Util::BasicTreeView *elements;
    QStackedWidget *pageContainer;
    QWidget *emptyPage;
    QWidget *editionPage;
    QVBoxLayout *verticalLayout;
    QLabel *lEditionEntry;
    QFrame *line_2;
    QGridLayout *gridLayout_2;
    QLabel *lEdFlags;
    QHBoxLayout *horizontalLayout_4;
    QCheckBox *cbEdFlagDefault;
    QCheckBox *cbEdFlagHidden;
    QCheckBox *cbEdFlagOrdered;
    QSpacerItem *horizontalSpacer_2;
    QLabel *lEdUid;
    mtx::gui::Util::BasicLineEdit *leEdUid;
    QSpacerItem *verticalSpacer;
    QWidget *chapterPage;
    QVBoxLayout *verticalLayout_7;
    mtx::gui::Util::ElideLabel *lChapter;
    QFrame *line_3;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout;
    QCheckBox *cbChFlagEnabled;
    QCheckBox *cbChFlagHidden;
    QSpacerItem *horizontalSpacer;
    QLabel *lChFlags;
    QHBoxLayout *horizontalLayout_2;
    mtx::gui::Util::BasicLineEdit *leChStart;
    mtx::gui::Util::BasicLineEdit *leChEnd;
    mtx::gui::Util::BasicLineEdit *leChSegmentEditionUid;
    mtx::gui::Util::BasicLineEdit *leChUid;
    QLabel *lChSegmentUid;
    QLabel *lChStart;
    QLabel *lChSegmentEditionUid;
    QLabel *lChUid;
    QHBoxLayout *horizontalLayout_5;
    mtx::gui::Util::BasicLineEdit *leChSegmentUid;
    QPushButton *pbBrowseSegmentUID;
    QGroupBox *gbChNames;
    QVBoxLayout *verticalLayout_8;
    QHBoxLayout *horizontalLayout_3;
    mtx::gui::Util::BasicTreeView *tvChNames;
    QVBoxLayout *verticalLayout_3;
    QPushButton *pbChAddName;
    QPushButton *pbChRemoveName;
    QSpacerItem *verticalSpacer_2;
    QGridLayout *gridLayout_4;
    mtx::gui::Util::BasicLineEdit *leChName;
    QLabel *lChName;
    QWidget *wChNameLanguages;
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout_6;
    mtx::gui::Util::LanguageDisplayWidget *ldwChNameLanguage1;
    QPushButton *pbChNameLanguageAdd;
    QLabel *lChNameLanguage;

    void setupUi(QWidget *mtx__gui__ChapterEditor__Tab)
    {
        if (mtx__gui__ChapterEditor__Tab->objectName().isEmpty())
            mtx__gui__ChapterEditor__Tab->setObjectName("mtx__gui__ChapterEditor__Tab");
        mtx__gui__ChapterEditor__Tab->resize(911, 670);
        mtx__gui__ChapterEditor__Tab->setWindowTitle(QString::fromUtf8("Form"));
        verticalLayout_5 = new QVBoxLayout(mtx__gui__ChapterEditor__Tab);
        verticalLayout_5->setObjectName("verticalLayout_5");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        fileNameLabel = new QLabel(mtx__gui__ChapterEditor__Tab);
        fileNameLabel->setObjectName("fileNameLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(fileNameLabel->sizePolicy().hasHeightForWidth());
        fileNameLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(fileNameLabel, 0, 0, 1, 1);

        fileName = new mtx::gui::Util::ElideLabel(mtx__gui__ChapterEditor__Tab);
        fileName->setObjectName("fileName");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(fileName->sizePolicy().hasHeightForWidth());
        fileName->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(fileName, 0, 1, 1, 1);

        directoryLabel = new QLabel(mtx__gui__ChapterEditor__Tab);
        directoryLabel->setObjectName("directoryLabel");
        sizePolicy.setHeightForWidth(directoryLabel->sizePolicy().hasHeightForWidth());
        directoryLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(directoryLabel, 1, 0, 1, 1);

        directory = new mtx::gui::Util::ElideLabel(mtx__gui__ChapterEditor__Tab);
        directory->setObjectName("directory");
        sizePolicy1.setHeightForWidth(directory->sizePolicy().hasHeightForWidth());
        directory->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(directory, 1, 1, 1, 1);


        verticalLayout_5->addLayout(gridLayout);

        line = new QFrame(mtx__gui__ChapterEditor__Tab);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_5->addWidget(line);

        chapterEditorSplitter = new QSplitter(mtx__gui__ChapterEditor__Tab);
        chapterEditorSplitter->setObjectName("chapterEditorSplitter");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(chapterEditorSplitter->sizePolicy().hasHeightForWidth());
        chapterEditorSplitter->setSizePolicy(sizePolicy2);
        chapterEditorSplitter->setOrientation(Qt::Horizontal);
        chapterEditorSplitter->setChildrenCollapsible(false);
        elements = new mtx::gui::Util::BasicTreeView(chapterEditorSplitter);
        elements->setObjectName("elements");
        sizePolicy2.setHeightForWidth(elements->sizePolicy().hasHeightForWidth());
        elements->setSizePolicy(sizePolicy2);
        elements->setContextMenuPolicy(Qt::CustomContextMenu);
        elements->setEditTriggers(QAbstractItemView::NoEditTriggers);
        elements->setDragEnabled(true);
        elements->setDragDropMode(QAbstractItemView::InternalMove);
        elements->setDefaultDropAction(Qt::MoveAction);
        elements->setHeaderHidden(false);
        chapterEditorSplitter->addWidget(elements);
        elements->header()->setVisible(true);
        pageContainer = new QStackedWidget(chapterEditorSplitter);
        pageContainer->setObjectName("pageContainer");
        sizePolicy2.setHeightForWidth(pageContainer->sizePolicy().hasHeightForWidth());
        pageContainer->setSizePolicy(sizePolicy2);
        emptyPage = new QWidget();
        emptyPage->setObjectName("emptyPage");
        pageContainer->addWidget(emptyPage);
        editionPage = new QWidget();
        editionPage->setObjectName("editionPage");
        verticalLayout = new QVBoxLayout(editionPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(6, 0, 0, 0);
        lEditionEntry = new QLabel(editionPage);
        lEditionEntry->setObjectName("lEditionEntry");

        verticalLayout->addWidget(lEditionEntry);

        line_2 = new QFrame(editionPage);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line_2);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        lEdFlags = new QLabel(editionPage);
        lEdFlags->setObjectName("lEdFlags");

        gridLayout_2->addWidget(lEdFlags, 0, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        cbEdFlagDefault = new QCheckBox(editionPage);
        cbEdFlagDefault->setObjectName("cbEdFlagDefault");

        horizontalLayout_4->addWidget(cbEdFlagDefault);

        cbEdFlagHidden = new QCheckBox(editionPage);
        cbEdFlagHidden->setObjectName("cbEdFlagHidden");

        horizontalLayout_4->addWidget(cbEdFlagHidden);

        cbEdFlagOrdered = new QCheckBox(editionPage);
        cbEdFlagOrdered->setObjectName("cbEdFlagOrdered");

        horizontalLayout_4->addWidget(cbEdFlagOrdered);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_2);


        gridLayout_2->addLayout(horizontalLayout_4, 0, 1, 1, 1);

        lEdUid = new QLabel(editionPage);
        lEdUid->setObjectName("lEdUid");

        gridLayout_2->addWidget(lEdUid, 1, 0, 1, 1);

        leEdUid = new mtx::gui::Util::BasicLineEdit(editionPage);
        leEdUid->setObjectName("leEdUid");

        gridLayout_2->addWidget(leEdUid, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout_2);

        verticalSpacer = new QSpacerItem(20, 334, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        pageContainer->addWidget(editionPage);
        chapterPage = new QWidget();
        chapterPage->setObjectName("chapterPage");
        verticalLayout_7 = new QVBoxLayout(chapterPage);
        verticalLayout_7->setObjectName("verticalLayout_7");
        verticalLayout_7->setContentsMargins(-1, 0, 0, 0);
        lChapter = new mtx::gui::Util::ElideLabel(chapterPage);
        lChapter->setObjectName("lChapter");
        lChapter->setText(QString::fromUtf8("Chapter XYZ"));

        verticalLayout_7->addWidget(lChapter);

        line_3 = new QFrame(chapterPage);
        line_3->setObjectName("line_3");
        line_3->setFrameShape(QFrame::Shape::HLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_7->addWidget(line_3);

        scrollArea = new QScrollArea(chapterPage);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 544, 558));
        verticalLayout_2 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_2->setObjectName("verticalLayout_2");
        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName("gridLayout_3");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        cbChFlagEnabled = new QCheckBox(scrollAreaWidgetContents);
        cbChFlagEnabled->setObjectName("cbChFlagEnabled");

        horizontalLayout->addWidget(cbChFlagEnabled);

        cbChFlagHidden = new QCheckBox(scrollAreaWidgetContents);
        cbChFlagHidden->setObjectName("cbChFlagHidden");

        horizontalLayout->addWidget(cbChFlagHidden);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout_3->addLayout(horizontalLayout, 1, 1, 1, 1);

        lChFlags = new QLabel(scrollAreaWidgetContents);
        lChFlags->setObjectName("lChFlags");

        gridLayout_3->addWidget(lChFlags, 1, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        leChStart = new mtx::gui::Util::BasicLineEdit(scrollAreaWidgetContents);
        leChStart->setObjectName("leChStart");

        horizontalLayout_2->addWidget(leChStart);

        leChEnd = new mtx::gui::Util::BasicLineEdit(scrollAreaWidgetContents);
        leChEnd->setObjectName("leChEnd");

        horizontalLayout_2->addWidget(leChEnd);


        gridLayout_3->addLayout(horizontalLayout_2, 0, 1, 1, 1);

        leChSegmentEditionUid = new mtx::gui::Util::BasicLineEdit(scrollAreaWidgetContents);
        leChSegmentEditionUid->setObjectName("leChSegmentEditionUid");

        gridLayout_3->addWidget(leChSegmentEditionUid, 4, 1, 1, 1);

        leChUid = new mtx::gui::Util::BasicLineEdit(scrollAreaWidgetContents);
        leChUid->setObjectName("leChUid");

        gridLayout_3->addWidget(leChUid, 2, 1, 1, 1);

        lChSegmentUid = new QLabel(scrollAreaWidgetContents);
        lChSegmentUid->setObjectName("lChSegmentUid");

        gridLayout_3->addWidget(lChSegmentUid, 3, 0, 1, 1);

        lChStart = new QLabel(scrollAreaWidgetContents);
        lChStart->setObjectName("lChStart");

        gridLayout_3->addWidget(lChStart, 0, 0, 1, 1);

        lChSegmentEditionUid = new QLabel(scrollAreaWidgetContents);
        lChSegmentEditionUid->setObjectName("lChSegmentEditionUid");

        gridLayout_3->addWidget(lChSegmentEditionUid, 4, 0, 1, 1);

        lChUid = new QLabel(scrollAreaWidgetContents);
        lChUid->setObjectName("lChUid");

        gridLayout_3->addWidget(lChUid, 2, 0, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        leChSegmentUid = new mtx::gui::Util::BasicLineEdit(scrollAreaWidgetContents);
        leChSegmentUid->setObjectName("leChSegmentUid");

        horizontalLayout_5->addWidget(leChSegmentUid);

        pbBrowseSegmentUID = new QPushButton(scrollAreaWidgetContents);
        pbBrowseSegmentUID->setObjectName("pbBrowseSegmentUID");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-open")));
        pbBrowseSegmentUID->setIcon(icon);

        horizontalLayout_5->addWidget(pbBrowseSegmentUID);


        gridLayout_3->addLayout(horizontalLayout_5, 3, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout_3);

        gbChNames = new QGroupBox(scrollAreaWidgetContents);
        gbChNames->setObjectName("gbChNames");
        verticalLayout_8 = new QVBoxLayout(gbChNames);
        verticalLayout_8->setObjectName("verticalLayout_8");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        tvChNames = new mtx::gui::Util::BasicTreeView(gbChNames);
        tvChNames->setObjectName("tvChNames");
        tvChNames->setDragEnabled(true);
        tvChNames->setDragDropMode(QAbstractItemView::InternalMove);
        tvChNames->setDefaultDropAction(Qt::MoveAction);

        horizontalLayout_3->addWidget(tvChNames);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        pbChAddName = new QPushButton(gbChNames);
        pbChAddName->setObjectName("pbChAddName");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("list-add")));
        pbChAddName->setIcon(icon1);

        verticalLayout_3->addWidget(pbChAddName);

        pbChRemoveName = new QPushButton(gbChNames);
        pbChRemoveName->setObjectName("pbChRemoveName");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        pbChRemoveName->setIcon(icon2);

        verticalLayout_3->addWidget(pbChRemoveName);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_2);


        horizontalLayout_3->addLayout(verticalLayout_3);


        verticalLayout_8->addLayout(horizontalLayout_3);

        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName("gridLayout_4");
        leChName = new mtx::gui::Util::BasicLineEdit(gbChNames);
        leChName->setObjectName("leChName");

        gridLayout_4->addWidget(leChName, 0, 1, 1, 1);

        lChName = new QLabel(gbChNames);
        lChName->setObjectName("lChName");

        gridLayout_4->addWidget(lChName, 0, 0, 1, 1);

        wChNameLanguages = new QWidget(gbChNames);
        wChNameLanguages->setObjectName("wChNameLanguages");
        verticalLayout_4 = new QVBoxLayout(wChNameLanguages);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        ldwChNameLanguage1 = new mtx::gui::Util::LanguageDisplayWidget(wChNameLanguages);
        ldwChNameLanguage1->setObjectName("ldwChNameLanguage1");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(ldwChNameLanguage1->sizePolicy().hasHeightForWidth());
        ldwChNameLanguage1->setSizePolicy(sizePolicy3);

        horizontalLayout_6->addWidget(ldwChNameLanguage1);

        pbChNameLanguageAdd = new QPushButton(wChNameLanguages);
        pbChNameLanguageAdd->setObjectName("pbChNameLanguageAdd");
        pbChNameLanguageAdd->setText(QString::fromUtf8(""));
        pbChNameLanguageAdd->setIcon(icon1);

        horizontalLayout_6->addWidget(pbChNameLanguageAdd);


        verticalLayout_4->addLayout(horizontalLayout_6);


        gridLayout_4->addWidget(wChNameLanguages, 1, 1, 1, 1);

        lChNameLanguage = new QLabel(gbChNames);
        lChNameLanguage->setObjectName("lChNameLanguage");

        gridLayout_4->addWidget(lChNameLanguage, 1, 0, 1, 1);


        verticalLayout_8->addLayout(gridLayout_4);


        verticalLayout_2->addWidget(gbChNames);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_7->addWidget(scrollArea);

        pageContainer->addWidget(chapterPage);
        chapterEditorSplitter->addWidget(pageContainer);

        verticalLayout_5->addWidget(chapterEditorSplitter);

#if QT_CONFIG(shortcut)
        lEdUid->setBuddy(leEdUid);
        lChSegmentUid->setBuddy(leChSegmentUid);
        lChStart->setBuddy(leChStart);
        lChSegmentEditionUid->setBuddy(leChSegmentEditionUid);
        lChUid->setBuddy(leChUid);
        lChName->setBuddy(leChName);
        lChNameLanguage->setBuddy(ldwChNameLanguage1);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(elements, cbEdFlagDefault);
        QWidget::setTabOrder(cbEdFlagDefault, cbEdFlagHidden);
        QWidget::setTabOrder(cbEdFlagHidden, cbEdFlagOrdered);
        QWidget::setTabOrder(cbEdFlagOrdered, leEdUid);
        QWidget::setTabOrder(leEdUid, scrollArea);
        QWidget::setTabOrder(scrollArea, leChStart);
        QWidget::setTabOrder(leChStart, leChEnd);
        QWidget::setTabOrder(leChEnd, cbChFlagEnabled);
        QWidget::setTabOrder(cbChFlagEnabled, cbChFlagHidden);
        QWidget::setTabOrder(cbChFlagHidden, leChUid);
        QWidget::setTabOrder(leChUid, leChSegmentUid);
        QWidget::setTabOrder(leChSegmentUid, pbBrowseSegmentUID);
        QWidget::setTabOrder(pbBrowseSegmentUID, leChSegmentEditionUid);
        QWidget::setTabOrder(leChSegmentEditionUid, tvChNames);
        QWidget::setTabOrder(tvChNames, pbChAddName);
        QWidget::setTabOrder(pbChAddName, pbChRemoveName);
        QWidget::setTabOrder(pbChRemoveName, leChName);
        QWidget::setTabOrder(leChName, ldwChNameLanguage1);

        retranslateUi(mtx__gui__ChapterEditor__Tab);

        pageContainer->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(mtx__gui__ChapterEditor__Tab);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__ChapterEditor__Tab)
    {
        fileNameLabel->setText(QTR("File name:", nullptr));
        directoryLabel->setText(QTR("Directory:", nullptr));
        lEditionEntry->setText(QTR("Edition entry", nullptr));
        lEdFlags->setText(QTR("Flags:", nullptr));
        cbEdFlagDefault->setText(QTR("&Default", nullptr));
        cbEdFlagHidden->setText(QTR("&Hidden", nullptr));
        cbEdFlagOrdered->setText(QTR("&Ordered", nullptr));
        lEdUid->setText(QTR("&UID:", nullptr));
        cbChFlagEnabled->setText(QTR("&Enabled", nullptr));
        cbChFlagHidden->setText(QTR("&Hidden", nullptr));
        lChFlags->setText(QTR("Flags:", nullptr));
        lChSegmentUid->setText(QTR("Seg&ment UID:", nullptr));
        lChStart->setText(QTR("&Start && end:", nullptr));
        lChSegmentEditionUid->setText(QTR("Segment e&dition UID:", nullptr));
        lChUid->setText(QTR("&UID:", nullptr));
        pbBrowseSegmentUID->setText(QString());
        gbChNames->setTitle(QTR("Names", nullptr));
        pbChAddName->setText(QString());
        pbChRemoveName->setText(QString());
        lChName->setText(QTR("&Name:", nullptr));
        lChNameLanguage->setText(QTR("Languages:", nullptr));
        (void)mtx__gui__ChapterEditor__Tab;
    } // retranslateUi

};

} // namespace ChapterEditor
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace ChapterEditor {
namespace Ui {
    class Tab: public Ui_Tab {};
} // namespace Ui
} // namespace ChapterEditor
} // namespace gui
} // namespace mtx

#endif // TAB_H
