/********************************************************************************
** Form generated from reading UI file 'tab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef TAB_H
#define TAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/util/elide_label.h"

namespace mtx {
namespace gui {
namespace WatchJobs {

class Ui_Tab
{
public:
    QVBoxLayout *verticalLayout_4;
    mtx::gui::Util::ElideLabel *description;
    QFrame *line;
    QGridLayout *gridLayout;
    QLabel *statusLabel;
    QLabel *status;
    QLabel *startedAtLabel;
    QLabel *startedAt;
    QLabel *progressLabel;
    QProgressBar *progressBar;
    QLabel *remainingTimeCurrentJobLabel;
    QLabel *remainingTimeCurrentJob;
    QLabel *finishedAtLabel;
    QLabel *finishedAt;
    QLabel *remainingTimeQueueLabel;
    QLabel *remainingTimeQueue;
    QSplitter *sOutput;
    QWidget *layoutWidget_1;
    QVBoxLayout *verticalLayout_3;
    QLabel *outputLabel;
    QPlainTextEdit *output;
    QSplitter *sWarningsErrors;
    QWidget *layoutWidget_2;
    QVBoxLayout *verticalLayout;
    QLabel *warningsLabel;
    QPlainTextEdit *warnings;
    QWidget *layoutWidget_3;
    QVBoxLayout *verticalLayout_2;
    QLabel *errorsLabel;
    QPlainTextEdit *errors;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *acknowledgeWarningsAndErrorsButton;
    QPushButton *abortButton;
    QPushButton *whenFinishedButton;
    QPushButton *moreActionsButton;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QWidget *mtx__gui__WatchJobs__Tab)
    {
        if (mtx__gui__WatchJobs__Tab->objectName().isEmpty())
            mtx__gui__WatchJobs__Tab->setObjectName("mtx__gui__WatchJobs__Tab");
        mtx__gui__WatchJobs__Tab->resize(900, 593);
        mtx__gui__WatchJobs__Tab->setWindowTitle(QString::fromUtf8("Form"));
        verticalLayout_4 = new QVBoxLayout(mtx__gui__WatchJobs__Tab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        description = new mtx::gui::Util::ElideLabel(mtx__gui__WatchJobs__Tab);
        description->setObjectName("description");

        verticalLayout_4->addWidget(description);

        line = new QFrame(mtx__gui__WatchJobs__Tab);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_4->addWidget(line);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        statusLabel = new QLabel(mtx__gui__WatchJobs__Tab);
        statusLabel->setObjectName("statusLabel");

        gridLayout->addWidget(statusLabel, 0, 0, 1, 1);

        status = new QLabel(mtx__gui__WatchJobs__Tab);
        status->setObjectName("status");

        gridLayout->addWidget(status, 0, 1, 1, 1);

        startedAtLabel = new QLabel(mtx__gui__WatchJobs__Tab);
        startedAtLabel->setObjectName("startedAtLabel");

        gridLayout->addWidget(startedAtLabel, 0, 2, 1, 1);

        startedAt = new QLabel(mtx__gui__WatchJobs__Tab);
        startedAt->setObjectName("startedAt");
        startedAt->setMinimumSize(QSize(140, 0));

        gridLayout->addWidget(startedAt, 0, 3, 1, 1);

        progressLabel = new QLabel(mtx__gui__WatchJobs__Tab);
        progressLabel->setObjectName("progressLabel");

        gridLayout->addWidget(progressLabel, 1, 0, 1, 1);

        progressBar = new QProgressBar(mtx__gui__WatchJobs__Tab);
        progressBar->setObjectName("progressBar");
        progressBar->setValue(0);

        gridLayout->addWidget(progressBar, 1, 1, 1, 1);

        remainingTimeCurrentJobLabel = new QLabel(mtx__gui__WatchJobs__Tab);
        remainingTimeCurrentJobLabel->setObjectName("remainingTimeCurrentJobLabel");

        gridLayout->addWidget(remainingTimeCurrentJobLabel, 2, 0, 1, 1);

        remainingTimeCurrentJob = new QLabel(mtx__gui__WatchJobs__Tab);
        remainingTimeCurrentJob->setObjectName("remainingTimeCurrentJob");
        remainingTimeCurrentJob->setText(QString::fromUtf8("\342\200\223"));

        gridLayout->addWidget(remainingTimeCurrentJob, 2, 1, 1, 1);

        finishedAtLabel = new QLabel(mtx__gui__WatchJobs__Tab);
        finishedAtLabel->setObjectName("finishedAtLabel");

        gridLayout->addWidget(finishedAtLabel, 1, 2, 1, 1);

        finishedAt = new QLabel(mtx__gui__WatchJobs__Tab);
        finishedAt->setObjectName("finishedAt");
        finishedAt->setMinimumSize(QSize(140, 0));

        gridLayout->addWidget(finishedAt, 1, 3, 1, 1);

        remainingTimeQueueLabel = new QLabel(mtx__gui__WatchJobs__Tab);
        remainingTimeQueueLabel->setObjectName("remainingTimeQueueLabel");

        gridLayout->addWidget(remainingTimeQueueLabel, 2, 2, 1, 1);

        remainingTimeQueue = new QLabel(mtx__gui__WatchJobs__Tab);
        remainingTimeQueue->setObjectName("remainingTimeQueue");
        remainingTimeQueue->setText(QString::fromUtf8("\342\200\223"));

        gridLayout->addWidget(remainingTimeQueue, 2, 3, 1, 1);


        verticalLayout_4->addLayout(gridLayout);

        sOutput = new QSplitter(mtx__gui__WatchJobs__Tab);
        sOutput->setObjectName("sOutput");
        sOutput->setOrientation(Qt::Vertical);
        layoutWidget_1 = new QWidget(sOutput);
        layoutWidget_1->setObjectName("layoutWidget_1");
        verticalLayout_3 = new QVBoxLayout(layoutWidget_1);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        outputLabel = new QLabel(layoutWidget_1);
        outputLabel->setObjectName("outputLabel");

        verticalLayout_3->addWidget(outputLabel);

        output = new QPlainTextEdit(layoutWidget_1);
        output->setObjectName("output");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(output->sizePolicy().hasHeightForWidth());
        output->setSizePolicy(sizePolicy);
        output->setUndoRedoEnabled(false);
        output->setReadOnly(true);

        verticalLayout_3->addWidget(output);

        sOutput->addWidget(layoutWidget_1);
        sWarningsErrors = new QSplitter(sOutput);
        sWarningsErrors->setObjectName("sWarningsErrors");
        sWarningsErrors->setOrientation(Qt::Horizontal);
        layoutWidget_2 = new QWidget(sWarningsErrors);
        layoutWidget_2->setObjectName("layoutWidget_2");
        verticalLayout = new QVBoxLayout(layoutWidget_2);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        warningsLabel = new QLabel(layoutWidget_2);
        warningsLabel->setObjectName("warningsLabel");

        verticalLayout->addWidget(warningsLabel);

        warnings = new QPlainTextEdit(layoutWidget_2);
        warnings->setObjectName("warnings");
        sizePolicy.setHeightForWidth(warnings->sizePolicy().hasHeightForWidth());
        warnings->setSizePolicy(sizePolicy);
        warnings->setUndoRedoEnabled(false);
        warnings->setReadOnly(true);

        verticalLayout->addWidget(warnings);

        sWarningsErrors->addWidget(layoutWidget_2);
        layoutWidget_3 = new QWidget(sWarningsErrors);
        layoutWidget_3->setObjectName("layoutWidget_3");
        verticalLayout_2 = new QVBoxLayout(layoutWidget_3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        errorsLabel = new QLabel(layoutWidget_3);
        errorsLabel->setObjectName("errorsLabel");

        verticalLayout_2->addWidget(errorsLabel);

        errors = new QPlainTextEdit(layoutWidget_3);
        errors->setObjectName("errors");
        sizePolicy.setHeightForWidth(errors->sizePolicy().hasHeightForWidth());
        errors->setSizePolicy(sizePolicy);
        errors->setUndoRedoEnabled(false);
        errors->setReadOnly(true);

        verticalLayout_2->addWidget(errors);

        sWarningsErrors->addWidget(layoutWidget_3);
        sOutput->addWidget(sWarningsErrors);

        verticalLayout_4->addWidget(sOutput);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        acknowledgeWarningsAndErrorsButton = new QPushButton(mtx__gui__WatchJobs__Tab);
        acknowledgeWarningsAndErrorsButton->setObjectName("acknowledgeWarningsAndErrorsButton");
        acknowledgeWarningsAndErrorsButton->setEnabled(false);

        horizontalLayout->addWidget(acknowledgeWarningsAndErrorsButton);

        abortButton = new QPushButton(mtx__gui__WatchJobs__Tab);
        abortButton->setObjectName("abortButton");
        abortButton->setEnabled(false);

        horizontalLayout->addWidget(abortButton);

        whenFinishedButton = new QPushButton(mtx__gui__WatchJobs__Tab);
        whenFinishedButton->setObjectName("whenFinishedButton");

        horizontalLayout->addWidget(whenFinishedButton);

        moreActionsButton = new QPushButton(mtx__gui__WatchJobs__Tab);
        moreActionsButton->setObjectName("moreActionsButton");

        horizontalLayout->addWidget(moreActionsButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout_4->addLayout(horizontalLayout);

#if QT_CONFIG(shortcut)
        outputLabel->setBuddy(output);
        warningsLabel->setBuddy(warnings);
        errorsLabel->setBuddy(errors);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(output, warnings);
        QWidget::setTabOrder(warnings, errors);
        QWidget::setTabOrder(errors, acknowledgeWarningsAndErrorsButton);
        QWidget::setTabOrder(acknowledgeWarningsAndErrorsButton, abortButton);
        QWidget::setTabOrder(abortButton, whenFinishedButton);
        QWidget::setTabOrder(whenFinishedButton, moreActionsButton);

        retranslateUi(mtx__gui__WatchJobs__Tab);

        QMetaObject::connectSlotsByName(mtx__gui__WatchJobs__Tab);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__WatchJobs__Tab)
    {
        statusLabel->setText(QTR("Status:", nullptr));
        status->setText(QTR("No job started yet", nullptr));
        startedAtLabel->setText(QTR("Started at:", nullptr));
        startedAt->setText(QTR("Not started yet", nullptr));
        progressLabel->setText(QTR("Progress:", nullptr));
        remainingTimeCurrentJobLabel->setText(QTR("Remaining time for current job:", nullptr));
        finishedAtLabel->setText(QTR("Finished at:", nullptr));
        finishedAt->setText(QTR("Not finished yet", nullptr));
        remainingTimeQueueLabel->setText(QTR("Remaining time for queue:", nullptr));
        outputLabel->setText(QTR("Nor&mal output:", nullptr));
        warningsLabel->setText(QTR("Warnings:", nullptr));
        errorsLabel->setText(QTR("Errors:", nullptr));
        acknowledgeWarningsAndErrorsButton->setText(QTR("A&cknowledge warnings/errors", nullptr));
        abortButton->setText(QTR("&Abort job", nullptr));
        whenFinishedButton->setText(QTR("When &finished\342\200\246", nullptr));
        moreActionsButton->setText(QTR("M&ore actions", nullptr));
        (void)mtx__gui__WatchJobs__Tab;
    } // retranslateUi

};

} // namespace WatchJobs
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace WatchJobs {
namespace Ui {
    class Tab: public Ui_Tab {};
} // namespace Ui
} // namespace WatchJobs
} // namespace gui
} // namespace mtx

#endif // TAB_H
