/********************************************************************************
** Form generated from reading UI file 'select_character_set_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef SELECT_CHARACTER_SET_DIALOG_H
#define SELECT_CHARACTER_SET_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "mkvtoolnix-gui/util/character_set_combo_box.h"
#include "mkvtoolnix-gui/util/elide_label.h"

namespace mtx {
namespace gui {

class Ui_SelectCharacterSetDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *title;
    QFrame *line;
    QLabel *introduction;
    QFormLayout *formLayout;
    QLabel *fileNameLabel;
    mtx::gui::Util::ElideLabel *fileName;
    QLabel *characterSetLabel;
    mtx::gui::Util::CharacterSetComboBox *characterSet;
    QVBoxLayout *verticalLayout;
    QLabel *previewLabel;
    QSpacerItem *verticalSpacer;
    QPlainTextEdit *content;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *mtx__gui__SelectCharacterSetDialog)
    {
        if (mtx__gui__SelectCharacterSetDialog->objectName().isEmpty())
            mtx__gui__SelectCharacterSetDialog->setObjectName("mtx__gui__SelectCharacterSetDialog");
        mtx__gui__SelectCharacterSetDialog->resize(648, 362);
        verticalLayout_2 = new QVBoxLayout(mtx__gui__SelectCharacterSetDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        title = new QLabel(mtx__gui__SelectCharacterSetDialog);
        title->setObjectName("title");

        verticalLayout_2->addWidget(title);

        line = new QFrame(mtx__gui__SelectCharacterSetDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(line);

        introduction = new QLabel(mtx__gui__SelectCharacterSetDialog);
        introduction->setObjectName("introduction");

        verticalLayout_2->addWidget(introduction);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        fileNameLabel = new QLabel(mtx__gui__SelectCharacterSetDialog);
        fileNameLabel->setObjectName("fileNameLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, fileNameLabel);

        fileName = new mtx::gui::Util::ElideLabel(mtx__gui__SelectCharacterSetDialog);
        fileName->setObjectName("fileName");
        fileName->setText(QString::fromUtf8("file name"));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, fileName);

        characterSetLabel = new QLabel(mtx__gui__SelectCharacterSetDialog);
        characterSetLabel->setObjectName("characterSetLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, characterSetLabel);

        characterSet = new mtx::gui::Util::CharacterSetComboBox(mtx__gui__SelectCharacterSetDialog);
        characterSet->setObjectName("characterSet");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(characterSet->sizePolicy().hasHeightForWidth());
        characterSet->setSizePolicy(sizePolicy);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, characterSet);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        previewLabel = new QLabel(mtx__gui__SelectCharacterSetDialog);
        previewLabel->setObjectName("previewLabel");

        verticalLayout->addWidget(previewLabel);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        formLayout->setLayout(2, QFormLayout::ItemRole::LabelRole, verticalLayout);

        content = new QPlainTextEdit(mtx__gui__SelectCharacterSetDialog);
        content->setObjectName("content");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(1);
        sizePolicy1.setHeightForWidth(content->sizePolicy().hasHeightForWidth());
        content->setSizePolicy(sizePolicy1);
        content->setReadOnly(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, content);


        verticalLayout_2->addLayout(formLayout);

        buttonBox = new QDialogButtonBox(mtx__gui__SelectCharacterSetDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        characterSetLabel->setBuddy(characterSet);
        previewLabel->setBuddy(content);
#endif // QT_CONFIG(shortcut)

        retranslateUi(mtx__gui__SelectCharacterSetDialog);

        QMetaObject::connectSlotsByName(mtx__gui__SelectCharacterSetDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__SelectCharacterSetDialog)
    {
        mtx__gui__SelectCharacterSetDialog->setWindowTitle(QTR("Select character set", nullptr));
        title->setText(QTR("Select character set", nullptr));
        introduction->setText(QTR("Please select the character set the following file is encoded in.", nullptr));
        fileNameLabel->setText(QTR("File name:", nullptr));
        characterSetLabel->setText(QTR("&Character set:", nullptr));
        previewLabel->setText(QTR("Pre&view:", nullptr));
    } // retranslateUi

};

} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Ui {
    class SelectCharacterSetDialog: public Ui_SelectCharacterSetDialog {};
} // namespace Ui
} // namespace gui
} // namespace mtx

#endif // SELECT_CHARACTER_SET_DIALOG_H
