/********************************************************************************
** Form generated from reading UI file 'select_disc_library_information_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef SELECT_DISC_LIBRARY_INFORMATION_DIALOG_H
#define SELECT_DISC_LIBRARY_INFORMATION_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include "mkvtoolnix-gui/merge/disc_library_information_widget.h"

namespace mtx {
namespace gui {
namespace Merge {

class Ui_SelectDiscLibraryInformationDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    mtx::gui::Merge::DiscLibraryInformationWidget *discLibrary;
    QDialogButtonBox *buttons;

    void setupUi(QDialog *mtx__gui__Merge__SelectDiscLibraryInformationDialog)
    {
        if (mtx__gui__Merge__SelectDiscLibraryInformationDialog->objectName().isEmpty())
            mtx__gui__Merge__SelectDiscLibraryInformationDialog->setObjectName("mtx__gui__Merge__SelectDiscLibraryInformationDialog");
        mtx__gui__Merge__SelectDiscLibraryInformationDialog->resize(573, 373);
        verticalLayout = new QVBoxLayout(mtx__gui__Merge__SelectDiscLibraryInformationDialog);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(mtx__gui__Merge__SelectDiscLibraryInformationDialog);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        discLibrary = new mtx::gui::Merge::DiscLibraryInformationWidget(mtx__gui__Merge__SelectDiscLibraryInformationDialog);
        discLibrary->setObjectName("discLibrary");
        discLibrary->setEditTriggers(QAbstractItemView::NoEditTriggers);
        discLibrary->setProperty("showDropIndicator", QVariant(false));

        verticalLayout->addWidget(discLibrary);

        buttons = new QDialogButtonBox(mtx__gui__Merge__SelectDiscLibraryInformationDialog);
        buttons->setObjectName("buttons");
        buttons->setOrientation(Qt::Horizontal);
        buttons->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttons);


        retranslateUi(mtx__gui__Merge__SelectDiscLibraryInformationDialog);
        QObject::connect(buttons, &QDialogButtonBox::accepted, mtx__gui__Merge__SelectDiscLibraryInformationDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttons, &QDialogButtonBox::rejected, mtx__gui__Merge__SelectDiscLibraryInformationDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(mtx__gui__Merge__SelectDiscLibraryInformationDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__Merge__SelectDiscLibraryInformationDialog)
    {
        mtx__gui__Merge__SelectDiscLibraryInformationDialog->setWindowTitle(QTR("Disc library information selection", nullptr));
        label->setText(QTR("Select disc library information to use", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = discLibrary->headerItem();
        ___qtreewidgetitem->setText(3, QTR("Size", nullptr));
        ___qtreewidgetitem->setText(2, QTR("Cover image", nullptr));
        ___qtreewidgetitem->setText(1, QTR("Title", nullptr));
        ___qtreewidgetitem->setText(0, QTR("Language", nullptr));
    } // retranslateUi

};

} // namespace Merge
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Merge {
namespace Ui {
    class SelectDiscLibraryInformationDialog: public Ui_SelectDiscLibraryInformationDialog {};
} // namespace Ui
} // namespace Merge
} // namespace gui
} // namespace mtx

#endif // SELECT_DISC_LIBRARY_INFORMATION_DIALOG_H
