/********************************************************************************
** Form generated from reading UI file 'status_bar_progress_widget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef STATUS_BAR_PROGRESS_WIDGET_H
#define STATUS_BAR_PROGRESS_WIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QWidget>

namespace mtx {
namespace gui {

class Ui_StatusBarProgressWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QFrame *line;
    QLabel *jobsToExecuteLabel;
    QLabel *numJobsLabel;
    QFrame *line_3;
    QWidget *warningsContainer;
    QHBoxLayout *horizontalLayout_2;
    QLabel *warningsIconLabel;
    QLabel *warningsLabel;
    QWidget *errorsContainer;
    QHBoxLayout *horizontalLayout_3;
    QLabel *errorsIconLabel;
    QLabel *errorsLabel;
    QFrame *line_2;
    QLabel *progressLabel;
    QProgressBar *progress;
    QProgressBar *totalProgress;

    void setupUi(QWidget *mtx__gui__StatusBarProgressWidget)
    {
        if (mtx__gui__StatusBarProgressWidget->objectName().isEmpty())
            mtx__gui__StatusBarProgressWidget->setObjectName("mtx__gui__StatusBarProgressWidget");
        mtx__gui__StatusBarProgressWidget->resize(681, 25);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mtx__gui__StatusBarProgressWidget->sizePolicy().hasHeightForWidth());
        mtx__gui__StatusBarProgressWidget->setSizePolicy(sizePolicy);
        mtx__gui__StatusBarProgressWidget->setWindowTitle(QString::fromUtf8("mtx::gui::StatusBarProgressWidget"));
        horizontalLayout = new QHBoxLayout(mtx__gui__StatusBarProgressWidget);
        horizontalLayout->setSpacing(6);
        horizontalLayout->setContentsMargins(11, 11, 11, 11);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        line = new QFrame(mtx__gui__StatusBarProgressWidget);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::VLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        horizontalLayout->addWidget(line);

        jobsToExecuteLabel = new QLabel(mtx__gui__StatusBarProgressWidget);
        jobsToExecuteLabel->setObjectName("jobsToExecuteLabel");

        horizontalLayout->addWidget(jobsToExecuteLabel);

        numJobsLabel = new QLabel(mtx__gui__StatusBarProgressWidget);
        numJobsLabel->setObjectName("numJobsLabel");
        sizePolicy.setHeightForWidth(numJobsLabel->sizePolicy().hasHeightForWidth());
        numJobsLabel->setSizePolicy(sizePolicy);
        numJobsLabel->setText(QString::fromUtf8("0 automatic, 0 manual, 0 running"));

        horizontalLayout->addWidget(numJobsLabel);

        line_3 = new QFrame(mtx__gui__StatusBarProgressWidget);
        line_3->setObjectName("line_3");
        line_3->setFrameShape(QFrame::Shape::VLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        horizontalLayout->addWidget(line_3);

        warningsContainer = new QWidget(mtx__gui__StatusBarProgressWidget);
        warningsContainer->setObjectName("warningsContainer");
        warningsContainer->setContextMenuPolicy(Qt::CustomContextMenu);
        horizontalLayout_2 = new QHBoxLayout(warningsContainer);
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        warningsIconLabel = new QLabel(warningsContainer);
        warningsIconLabel->setObjectName("warningsIconLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(warningsIconLabel->sizePolicy().hasHeightForWidth());
        warningsIconLabel->setSizePolicy(sizePolicy1);
        warningsIconLabel->setMinimumSize(QSize(16, 16));
        warningsIconLabel->setMaximumSize(QSize(16, 16));
        warningsIconLabel->setText(QString::fromUtf8(""));
        warningsIconLabel->setPixmap(QPixmap(QString::fromUtf8(":/icons/mkvtoolnix-gui/oxygen/small/16x16/dialog-warning-grayscale.svg")));
        warningsIconLabel->setScaledContents(true);

        horizontalLayout_2->addWidget(warningsIconLabel);

        warningsLabel = new QLabel(warningsContainer);
        warningsLabel->setObjectName("warningsLabel");
        warningsLabel->setText(QString::fromUtf8("0 warnings"));

        horizontalLayout_2->addWidget(warningsLabel);


        horizontalLayout->addWidget(warningsContainer);

        errorsContainer = new QWidget(mtx__gui__StatusBarProgressWidget);
        errorsContainer->setObjectName("errorsContainer");
        errorsContainer->setContextMenuPolicy(Qt::CustomContextMenu);
        horizontalLayout_3 = new QHBoxLayout(errorsContainer);
        horizontalLayout_3->setSpacing(6);
        horizontalLayout_3->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(0, 0, 0, 0);
        errorsIconLabel = new QLabel(errorsContainer);
        errorsIconLabel->setObjectName("errorsIconLabel");
        errorsIconLabel->setMaximumSize(QSize(16, 16));
        errorsIconLabel->setText(QString::fromUtf8(""));
        errorsIconLabel->setPixmap(QPixmap(QString::fromUtf8(":/icons/mkvtoolnix-gui/oxygen/small/16x16/dialog-error-grayscale.svg")));
        errorsIconLabel->setScaledContents(true);

        horizontalLayout_3->addWidget(errorsIconLabel);

        errorsLabel = new QLabel(errorsContainer);
        errorsLabel->setObjectName("errorsLabel");
        errorsLabel->setText(QString::fromUtf8("0 errors"));

        horizontalLayout_3->addWidget(errorsLabel);


        horizontalLayout->addWidget(errorsContainer);

        line_2 = new QFrame(mtx__gui__StatusBarProgressWidget);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::VLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        horizontalLayout->addWidget(line_2);

        progressLabel = new QLabel(mtx__gui__StatusBarProgressWidget);
        progressLabel->setObjectName("progressLabel");

        horizontalLayout->addWidget(progressLabel);

        progress = new QProgressBar(mtx__gui__StatusBarProgressWidget);
        progress->setObjectName("progress");
        sizePolicy1.setHeightForWidth(progress->sizePolicy().hasHeightForWidth());
        progress->setSizePolicy(sizePolicy1);
        progress->setValue(0);

        horizontalLayout->addWidget(progress);

        totalProgress = new QProgressBar(mtx__gui__StatusBarProgressWidget);
        totalProgress->setObjectName("totalProgress");
        sizePolicy1.setHeightForWidth(totalProgress->sizePolicy().hasHeightForWidth());
        totalProgress->setSizePolicy(sizePolicy1);
        totalProgress->setValue(0);

        horizontalLayout->addWidget(totalProgress);


        retranslateUi(mtx__gui__StatusBarProgressWidget);

        QMetaObject::connectSlotsByName(mtx__gui__StatusBarProgressWidget);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__StatusBarProgressWidget)
    {
        jobsToExecuteLabel->setText(QTR("Jobs to execute:", nullptr));
        progressLabel->setText(QTR("Progress:", nullptr));
        progress->setFormat(QTR("%p%", nullptr));
        totalProgress->setFormat(QTR("%p%", nullptr));
        (void)mtx__gui__StatusBarProgressWidget;
    } // retranslateUi

};

} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Ui {
    class StatusBarProgressWidget: public Ui_StatusBarProgressWidget {};
} // namespace Ui
} // namespace gui
} // namespace mtx

#endif // STATUS_BAR_PROGRESS_WIDGET_H
