/********************************************************************************
** Form generated from reading UI file 'main_window.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef MAIN_WINDOW_H
#define MAIN_WINDOW_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenu>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/util/fancy_tab_widget.h"

namespace mtx {
namespace gui {

class Ui_MainWindow
{
public:
    QAction *actionMergeNew;
    QAction *actionMergeSave;
    QAction *actionMergeOpen;
    QAction *actionMergeSaveAs;
    QAction *actionGUIExit;
    QAction *actionMergeStartMuxing;
    QAction *actionMergeSaveOptionFile;
    QAction *actionMergeShowMkvmergeCommandLine;
    QAction *actionMergeCopyCommandLineToClipboard;
    QAction *actionMergeAddToJobQueue;
    QAction *actionGUIPreferences;
    QAction *actionHelpCheckForUpdates;
    QAction *actionHelpCodeOfConduct;
    QAction *actionHeaderEditorOpen;
    QAction *actionHeaderEditorClose;
    QAction *actionHeaderEditorSave;
    QAction *actionHeaderEditorReload;
    QAction *actionHeaderEditorValidate;
    QAction *actionChapterEditorNew;
    QAction *actionChapterEditorOpen;
    QAction *actionChapterEditorAppend;
    QAction *actionChapterEditorClose;
    QAction *actionChapterEditorSave;
    QAction *actionChapterEditorSaveAsXml;
    QAction *actionChapterEditorSaveToMatroska;
    QAction *actionChapterEditorReload;
    QAction *actionGUIMergeTool;
    QAction *actionGUIExtractionTool;
    QAction *actionGUIInfoTool;
    QAction *actionGUIHeaderEditor;
    QAction *actionGUIChapterEditor;
    QAction *actionGUIJobQueue;
    QAction *actionGUIJobOutput;
    QAction *actionGUITagEditor;
    QAction *actionMergeClose;
    QAction *actionJobOutputSave;
    QAction *actionJobOutputClose;
    QAction *actionHelpWebSite;
    QAction *actionHelpForum;
    QAction *actionHelpFAQ;
    QAction *actionHelpKnownProblems;
    QAction *actionHelpReportBug;
    QAction *actionHelpSystemInformation;
    QAction *actionHelpMkvmergeDocumentation;
    QAction *actionJobQueueRemoveDoneOk;
    QAction *actionJobQueueRemoveAll;
    QAction *actionJobQueueAcknowledgeAllWarnings;
    QAction *actionJobQueueAcknowledgeAllErrors;
    QAction *actionJobQueueAcknowledgeAllWarningsErrors;
    QAction *actionJobQueueRemoveDone;
    QAction *actionJobQueueStartAllPending;
    QAction *actionJobQueueStopAfterCurrentJob;
    QAction *actionJobQueueStopImmediately;
    QAction *actionMergeCopyFirstFileNameToTitle;
    QAction *actionMergeCopyOutputFileNameToTitle;
    QAction *actionMergeCopyTitleToOutputFileName;
    QAction *actionChapterEditorRemoveFromMatroska;
    QAction *actionChapterEditorCloseAll;
    QAction *actionChapterEditorSaveAll;
    QAction *actionHeaderEditorCloseAll;
    QAction *actionHeaderEditorSaveAll;
    QAction *actionMergeCloseAll;
    QAction *actionMergeSaveAll;
    QAction *actionMergeStartMuxingAll;
    QAction *actionMergeAddAllToJobQueue;
    QAction *actionJobOutputCloseAll;
    QAction *actionJobOutputSaveAll;
    QAction *actionWindowNext;
    QAction *actionWindowPrevious;
    QAction *actionInfoOpen;
    QAction *actionInfoClose;
    QAction *actionInfoCloseAll;
    QAction *actionInfoSave;
    QAction *actionMergeAddFilesFromClipboard;
    QAction *actionDbgMergeInputSetupHorizontalScrollAreaInputLayout;
    QAction *actionDbgMergeInputSetupHorizontalTwoColumnsInputLayout;
    QAction *actionDbgMergeInputSetupVerticalTabWidgetInputLayout;
    QAction *actionMergeSaveAllSingle;
    QAction *actionMergeSaveAllSingleAs;
    QWidget *centralWidget;
    QVBoxLayout *verticalLayout_2;
    QScrollArea *centralScrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout;
    mtx::gui::Util::FancyTabWidget *tool;
    QMenuBar *menuBar;
    QMenu *menuGUI;
    QMenu *menuMerge;
    QMenu *menuMergeAll;
    QMenu *menuMergeModifySelectedTracks;
    QMenu *menuHeaderEditor;
    QMenu *menuHeaderEditorAll;
    QMenu *menuHeaderEditorModifyTrack;
    QMenu *menuChapterEditor;
    QMenu *menuChapterEditorAll;
    QMenu *menuJobOutput;
    QMenu *menuJobOutputAll;
    QMenu *menuHelp;
    QMenu *menuJobQueue;
    QMenu *menuStopJobQueue;
    QMenu *menuWindow;
    QMenu *menuInfo;
    QMenu *menuDebugging;
    QMenu *menuDebuggingMerge;
    QStatusBar *statusBar;

    void setupUi(QMainWindow *mtx__gui__MainWindow)
    {
        if (mtx__gui__MainWindow->objectName().isEmpty())
            mtx__gui__MainWindow->setObjectName("mtx__gui__MainWindow");
        mtx__gui__MainWindow->resize(970, 700);
        mtx__gui__MainWindow->setWindowTitle(QString::fromUtf8("MainWindow"));
        actionMergeNew = new QAction(mtx__gui__MainWindow);
        actionMergeNew->setObjectName("actionMergeNew");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-new")));
        actionMergeNew->setIcon(icon);
        actionMergeSave = new QAction(mtx__gui__MainWindow);
        actionMergeSave->setObjectName("actionMergeSave");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("document-save")));
        actionMergeSave->setIcon(icon1);
        actionMergeOpen = new QAction(mtx__gui__MainWindow);
        actionMergeOpen->setObjectName("actionMergeOpen");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("document-open")));
        actionMergeOpen->setIcon(icon2);
        actionMergeSaveAs = new QAction(mtx__gui__MainWindow);
        actionMergeSaveAs->setObjectName("actionMergeSaveAs");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("document-save-as")));
        actionMergeSaveAs->setIcon(icon3);
        actionGUIExit = new QAction(mtx__gui__MainWindow);
        actionGUIExit->setObjectName("actionGUIExit");
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("application-exit")));
        actionGUIExit->setIcon(icon4);
        actionMergeStartMuxing = new QAction(mtx__gui__MainWindow);
        actionMergeStartMuxing->setObjectName("actionMergeStartMuxing");
        QIcon icon5(QIcon::fromTheme(QString::fromUtf8("media-playback-start")));
        actionMergeStartMuxing->setIcon(icon5);
        actionMergeSaveOptionFile = new QAction(mtx__gui__MainWindow);
        actionMergeSaveOptionFile->setObjectName("actionMergeSaveOptionFile");
        actionMergeShowMkvmergeCommandLine = new QAction(mtx__gui__MainWindow);
        actionMergeShowMkvmergeCommandLine->setObjectName("actionMergeShowMkvmergeCommandLine");
        QIcon icon6(QIcon::fromTheme(QString::fromUtf8("utilities-terminal")));
        actionMergeShowMkvmergeCommandLine->setIcon(icon6);
        actionMergeCopyCommandLineToClipboard = new QAction(mtx__gui__MainWindow);
        actionMergeCopyCommandLineToClipboard->setObjectName("actionMergeCopyCommandLineToClipboard");
        QIcon icon7(QIcon::fromTheme(QString::fromUtf8("edit-copy")));
        actionMergeCopyCommandLineToClipboard->setIcon(icon7);
        actionMergeAddToJobQueue = new QAction(mtx__gui__MainWindow);
        actionMergeAddToJobQueue->setObjectName("actionMergeAddToJobQueue");
        QIcon icon8(QIcon::fromTheme(QString::fromUtf8("task-delegate")));
        actionMergeAddToJobQueue->setIcon(icon8);
        actionGUIPreferences = new QAction(mtx__gui__MainWindow);
        actionGUIPreferences->setObjectName("actionGUIPreferences");
        QIcon icon9(QIcon::fromTheme(QString::fromUtf8("preferences-other")));
        actionGUIPreferences->setIcon(icon9);
        actionHelpCheckForUpdates = new QAction(mtx__gui__MainWindow);
        actionHelpCheckForUpdates->setObjectName("actionHelpCheckForUpdates");
        QIcon icon10(QIcon::fromTheme(QString::fromUtf8("system-software-update")));
        actionHelpCheckForUpdates->setIcon(icon10);
        actionHelpCodeOfConduct = new QAction(mtx__gui__MainWindow);
        actionHelpCodeOfConduct->setObjectName("actionHelpCodeOfConduct");
        QIcon icon11(QIcon::fromTheme(QString::fromUtf8("application-pgp-signature")));
        actionHelpCodeOfConduct->setIcon(icon11);
        actionHeaderEditorOpen = new QAction(mtx__gui__MainWindow);
        actionHeaderEditorOpen->setObjectName("actionHeaderEditorOpen");
        actionHeaderEditorOpen->setIcon(icon2);
        actionHeaderEditorClose = new QAction(mtx__gui__MainWindow);
        actionHeaderEditorClose->setObjectName("actionHeaderEditorClose");
        QIcon icon12(QIcon::fromTheme(QString::fromUtf8("document-close")));
        actionHeaderEditorClose->setIcon(icon12);
        actionHeaderEditorSave = new QAction(mtx__gui__MainWindow);
        actionHeaderEditorSave->setObjectName("actionHeaderEditorSave");
        actionHeaderEditorSave->setIcon(icon1);
        actionHeaderEditorReload = new QAction(mtx__gui__MainWindow);
        actionHeaderEditorReload->setObjectName("actionHeaderEditorReload");
        QIcon icon13(QIcon::fromTheme(QString::fromUtf8("document-revert")));
        actionHeaderEditorReload->setIcon(icon13);
        actionHeaderEditorValidate = new QAction(mtx__gui__MainWindow);
        actionHeaderEditorValidate->setObjectName("actionHeaderEditorValidate");
        QIcon icon14(QIcon::fromTheme(QString::fromUtf8("dialog-ok-apply")));
        actionHeaderEditorValidate->setIcon(icon14);
        actionChapterEditorNew = new QAction(mtx__gui__MainWindow);
        actionChapterEditorNew->setObjectName("actionChapterEditorNew");
        actionChapterEditorNew->setIcon(icon);
        actionChapterEditorOpen = new QAction(mtx__gui__MainWindow);
        actionChapterEditorOpen->setObjectName("actionChapterEditorOpen");
        actionChapterEditorOpen->setIcon(icon2);
        actionChapterEditorAppend = new QAction(mtx__gui__MainWindow);
        actionChapterEditorAppend->setObjectName("actionChapterEditorAppend");
        actionChapterEditorClose = new QAction(mtx__gui__MainWindow);
        actionChapterEditorClose->setObjectName("actionChapterEditorClose");
        actionChapterEditorClose->setIcon(icon12);
        actionChapterEditorSave = new QAction(mtx__gui__MainWindow);
        actionChapterEditorSave->setObjectName("actionChapterEditorSave");
        actionChapterEditorSave->setIcon(icon1);
        actionChapterEditorSaveAsXml = new QAction(mtx__gui__MainWindow);
        actionChapterEditorSaveAsXml->setObjectName("actionChapterEditorSaveAsXml");
        actionChapterEditorSaveToMatroska = new QAction(mtx__gui__MainWindow);
        actionChapterEditorSaveToMatroska->setObjectName("actionChapterEditorSaveToMatroska");
        actionChapterEditorReload = new QAction(mtx__gui__MainWindow);
        actionChapterEditorReload->setObjectName("actionChapterEditorReload");
        actionChapterEditorReload->setIcon(icon13);
        actionGUIMergeTool = new QAction(mtx__gui__MainWindow);
        actionGUIMergeTool->setObjectName("actionGUIMergeTool");
        QIcon icon15(QIcon::fromTheme(QString::fromUtf8("merge")));
        actionGUIMergeTool->setIcon(icon15);
        actionGUIExtractionTool = new QAction(mtx__gui__MainWindow);
        actionGUIExtractionTool->setObjectName("actionGUIExtractionTool");
        QIcon icon16(QIcon::fromTheme(QString::fromUtf8("split")));
        actionGUIExtractionTool->setIcon(icon16);
        actionGUIInfoTool = new QAction(mtx__gui__MainWindow);
        actionGUIInfoTool->setObjectName("actionGUIInfoTool");
        QIcon icon17(QIcon::fromTheme(QString::fromUtf8("document-preview-archive")));
        actionGUIInfoTool->setIcon(icon17);
        actionGUIHeaderEditor = new QAction(mtx__gui__MainWindow);
        actionGUIHeaderEditor->setObjectName("actionGUIHeaderEditor");
        QIcon icon18(QIcon::fromTheme(QString::fromUtf8("document-edit")));
        actionGUIHeaderEditor->setIcon(icon18);
        actionGUIChapterEditor = new QAction(mtx__gui__MainWindow);
        actionGUIChapterEditor->setObjectName("actionGUIChapterEditor");
        QIcon icon19(QIcon::fromTheme(QString::fromUtf8("story-editor")));
        actionGUIChapterEditor->setIcon(icon19);
        actionGUIJobQueue = new QAction(mtx__gui__MainWindow);
        actionGUIJobQueue->setObjectName("actionGUIJobQueue");
        QIcon icon20(QIcon::fromTheme(QString::fromUtf8("view-task")));
        actionGUIJobQueue->setIcon(icon20);
        actionGUIJobOutput = new QAction(mtx__gui__MainWindow);
        actionGUIJobOutput->setObjectName("actionGUIJobOutput");
        QIcon icon21(QIcon::fromTheme(QString::fromUtf8("system-run")));
        actionGUIJobOutput->setIcon(icon21);
        actionGUITagEditor = new QAction(mtx__gui__MainWindow);
        actionGUITagEditor->setObjectName("actionGUITagEditor");
        QIcon icon22(QIcon::fromTheme(QString::fromUtf8("document-edit-sign-encrypt")));
        actionGUITagEditor->setIcon(icon22);
        actionMergeClose = new QAction(mtx__gui__MainWindow);
        actionMergeClose->setObjectName("actionMergeClose");
        actionMergeClose->setIcon(icon12);
        actionJobOutputSave = new QAction(mtx__gui__MainWindow);
        actionJobOutputSave->setObjectName("actionJobOutputSave");
        actionJobOutputSave->setIcon(icon1);
        actionJobOutputClose = new QAction(mtx__gui__MainWindow);
        actionJobOutputClose->setObjectName("actionJobOutputClose");
        actionJobOutputClose->setIcon(icon12);
        actionHelpWebSite = new QAction(mtx__gui__MainWindow);
        actionHelpWebSite->setObjectName("actionHelpWebSite");
        QIcon icon23(QIcon::fromTheme(QString::fromUtf8("applications-internet")));
        actionHelpWebSite->setIcon(icon23);
        actionHelpForum = new QAction(mtx__gui__MainWindow);
        actionHelpForum->setObjectName("actionHelpForum");
        actionHelpForum->setIcon(icon23);
        actionHelpFAQ = new QAction(mtx__gui__MainWindow);
        actionHelpFAQ->setObjectName("actionHelpFAQ");
        actionHelpFAQ->setIcon(icon23);
        actionHelpKnownProblems = new QAction(mtx__gui__MainWindow);
        actionHelpKnownProblems->setObjectName("actionHelpKnownProblems");
        actionHelpKnownProblems->setIcon(icon23);
        actionHelpReportBug = new QAction(mtx__gui__MainWindow);
        actionHelpReportBug->setObjectName("actionHelpReportBug");
        QIcon icon24(QIcon::fromTheme(QString::fromUtf8("kbugbuster")));
        actionHelpReportBug->setIcon(icon24);
        actionHelpSystemInformation = new QAction(mtx__gui__MainWindow);
        actionHelpSystemInformation->setObjectName("actionHelpSystemInformation");
        actionHelpMkvmergeDocumentation = new QAction(mtx__gui__MainWindow);
        actionHelpMkvmergeDocumentation->setObjectName("actionHelpMkvmergeDocumentation");
        actionHelpMkvmergeDocumentation->setIcon(icon23);
        actionJobQueueRemoveDoneOk = new QAction(mtx__gui__MainWindow);
        actionJobQueueRemoveDoneOk->setObjectName("actionJobQueueRemoveDoneOk");
        actionJobQueueRemoveAll = new QAction(mtx__gui__MainWindow);
        actionJobQueueRemoveAll->setObjectName("actionJobQueueRemoveAll");
        QIcon icon25(QIcon::fromTheme(QString::fromUtf8("archive-remove")));
        actionJobQueueRemoveAll->setIcon(icon25);
        actionJobQueueAcknowledgeAllWarnings = new QAction(mtx__gui__MainWindow);
        actionJobQueueAcknowledgeAllWarnings->setObjectName("actionJobQueueAcknowledgeAllWarnings");
        actionJobQueueAcknowledgeAllErrors = new QAction(mtx__gui__MainWindow);
        actionJobQueueAcknowledgeAllErrors->setObjectName("actionJobQueueAcknowledgeAllErrors");
        actionJobQueueAcknowledgeAllWarningsErrors = new QAction(mtx__gui__MainWindow);
        actionJobQueueAcknowledgeAllWarningsErrors->setObjectName("actionJobQueueAcknowledgeAllWarningsErrors");
        actionJobQueueAcknowledgeAllWarningsErrors->setIcon(icon14);
        actionJobQueueRemoveDone = new QAction(mtx__gui__MainWindow);
        actionJobQueueRemoveDone->setObjectName("actionJobQueueRemoveDone");
        actionJobQueueStartAllPending = new QAction(mtx__gui__MainWindow);
        actionJobQueueStartAllPending->setObjectName("actionJobQueueStartAllPending");
        actionJobQueueStartAllPending->setIcon(icon5);
        actionJobQueueStopAfterCurrentJob = new QAction(mtx__gui__MainWindow);
        actionJobQueueStopAfterCurrentJob->setObjectName("actionJobQueueStopAfterCurrentJob");
        actionJobQueueStopImmediately = new QAction(mtx__gui__MainWindow);
        actionJobQueueStopImmediately->setObjectName("actionJobQueueStopImmediately");
        actionMergeCopyFirstFileNameToTitle = new QAction(mtx__gui__MainWindow);
        actionMergeCopyFirstFileNameToTitle->setObjectName("actionMergeCopyFirstFileNameToTitle");
        actionMergeCopyOutputFileNameToTitle = new QAction(mtx__gui__MainWindow);
        actionMergeCopyOutputFileNameToTitle->setObjectName("actionMergeCopyOutputFileNameToTitle");
        actionMergeCopyTitleToOutputFileName = new QAction(mtx__gui__MainWindow);
        actionMergeCopyTitleToOutputFileName->setObjectName("actionMergeCopyTitleToOutputFileName");
        actionChapterEditorRemoveFromMatroska = new QAction(mtx__gui__MainWindow);
        actionChapterEditorRemoveFromMatroska->setObjectName("actionChapterEditorRemoveFromMatroska");
        actionChapterEditorCloseAll = new QAction(mtx__gui__MainWindow);
        actionChapterEditorCloseAll->setObjectName("actionChapterEditorCloseAll");
        actionChapterEditorCloseAll->setIcon(icon12);
        actionChapterEditorSaveAll = new QAction(mtx__gui__MainWindow);
        actionChapterEditorSaveAll->setObjectName("actionChapterEditorSaveAll");
        actionChapterEditorSaveAll->setIcon(icon1);
        actionHeaderEditorCloseAll = new QAction(mtx__gui__MainWindow);
        actionHeaderEditorCloseAll->setObjectName("actionHeaderEditorCloseAll");
        actionHeaderEditorCloseAll->setIcon(icon12);
        actionHeaderEditorSaveAll = new QAction(mtx__gui__MainWindow);
        actionHeaderEditorSaveAll->setObjectName("actionHeaderEditorSaveAll");
        actionHeaderEditorSaveAll->setIcon(icon1);
        actionMergeCloseAll = new QAction(mtx__gui__MainWindow);
        actionMergeCloseAll->setObjectName("actionMergeCloseAll");
        actionMergeCloseAll->setIcon(icon12);
        actionMergeSaveAll = new QAction(mtx__gui__MainWindow);
        actionMergeSaveAll->setObjectName("actionMergeSaveAll");
        actionMergeSaveAll->setIcon(icon1);
        actionMergeStartMuxingAll = new QAction(mtx__gui__MainWindow);
        actionMergeStartMuxingAll->setObjectName("actionMergeStartMuxingAll");
        actionMergeStartMuxingAll->setIcon(icon5);
        actionMergeAddAllToJobQueue = new QAction(mtx__gui__MainWindow);
        actionMergeAddAllToJobQueue->setObjectName("actionMergeAddAllToJobQueue");
        actionMergeAddAllToJobQueue->setIcon(icon8);
        actionJobOutputCloseAll = new QAction(mtx__gui__MainWindow);
        actionJobOutputCloseAll->setObjectName("actionJobOutputCloseAll");
        actionJobOutputCloseAll->setIcon(icon12);
        actionJobOutputSaveAll = new QAction(mtx__gui__MainWindow);
        actionJobOutputSaveAll->setObjectName("actionJobOutputSaveAll");
        actionJobOutputSaveAll->setIcon(icon1);
        actionWindowNext = new QAction(mtx__gui__MainWindow);
        actionWindowNext->setObjectName("actionWindowNext");
        actionWindowNext->setText(QString::fromUtf8("Next"));
        actionWindowPrevious = new QAction(mtx__gui__MainWindow);
        actionWindowPrevious->setObjectName("actionWindowPrevious");
        actionWindowPrevious->setText(QString::fromUtf8("Previous"));
        actionInfoOpen = new QAction(mtx__gui__MainWindow);
        actionInfoOpen->setObjectName("actionInfoOpen");
        QIcon icon26(QIcon::fromTheme(QString::fromUtf8("document-open-folder")));
        actionInfoOpen->setIcon(icon26);
        actionInfoClose = new QAction(mtx__gui__MainWindow);
        actionInfoClose->setObjectName("actionInfoClose");
        actionInfoClose->setIcon(icon12);
        actionInfoCloseAll = new QAction(mtx__gui__MainWindow);
        actionInfoCloseAll->setObjectName("actionInfoCloseAll");
        actionInfoCloseAll->setIcon(icon12);
        actionInfoSave = new QAction(mtx__gui__MainWindow);
        actionInfoSave->setObjectName("actionInfoSave");
        actionInfoSave->setIcon(icon1);
        actionMergeAddFilesFromClipboard = new QAction(mtx__gui__MainWindow);
        actionMergeAddFilesFromClipboard->setObjectName("actionMergeAddFilesFromClipboard");
        actionDbgMergeInputSetupHorizontalScrollAreaInputLayout = new QAction(mtx__gui__MainWindow);
        actionDbgMergeInputSetupHorizontalScrollAreaInputLayout->setObjectName("actionDbgMergeInputSetupHorizontalScrollAreaInputLayout");
        actionDbgMergeInputSetupHorizontalScrollAreaInputLayout->setText(QString::fromUtf8("Input: setupHorizontal&ScrollAreaInputLayout"));
        actionDbgMergeInputSetupHorizontalTwoColumnsInputLayout = new QAction(mtx__gui__MainWindow);
        actionDbgMergeInputSetupHorizontalTwoColumnsInputLayout->setObjectName("actionDbgMergeInputSetupHorizontalTwoColumnsInputLayout");
        actionDbgMergeInputSetupHorizontalTwoColumnsInputLayout->setText(QString::fromUtf8("Input: setupHorizontal&TwoColumnsInputLayout"));
        actionDbgMergeInputSetupVerticalTabWidgetInputLayout = new QAction(mtx__gui__MainWindow);
        actionDbgMergeInputSetupVerticalTabWidgetInputLayout->setObjectName("actionDbgMergeInputSetupVerticalTabWidgetInputLayout");
        actionDbgMergeInputSetupVerticalTabWidgetInputLayout->setText(QString::fromUtf8("Input: setup&VerticalTabWidgetInputLayout"));
        actionMergeSaveAllSingle = new QAction(mtx__gui__MainWindow);
        actionMergeSaveAllSingle->setObjectName("actionMergeSaveAllSingle");
        QIcon icon27(QIcon::fromTheme(QIcon::ThemeIcon::DocumentSave));
        actionMergeSaveAllSingle->setIcon(icon27);
        actionMergeSaveAllSingleAs = new QAction(mtx__gui__MainWindow);
        actionMergeSaveAllSingleAs->setObjectName("actionMergeSaveAllSingleAs");
        QIcon icon28(QIcon::fromTheme(QIcon::ThemeIcon::DocumentSaveAs));
        actionMergeSaveAllSingleAs->setIcon(icon28);
        centralWidget = new QWidget(mtx__gui__MainWindow);
        centralWidget->setObjectName("centralWidget");
        verticalLayout_2 = new QVBoxLayout(centralWidget);
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setContentsMargins(11, 11, 11, 11);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        centralScrollArea = new QScrollArea(centralWidget);
        centralScrollArea->setObjectName("centralScrollArea");
        centralScrollArea->setFrameShape(QFrame::NoFrame);
        centralScrollArea->setFrameShadow(QFrame::Plain);
        centralScrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 940, 553));
        verticalLayout = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        tool = new mtx::gui::Util::FancyTabWidget(scrollAreaWidgetContents);
        tool->setObjectName("tool");

        verticalLayout->addWidget(tool);

        centralScrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_2->addWidget(centralScrollArea);

        mtx__gui__MainWindow->setCentralWidget(centralWidget);
        menuBar = new QMenuBar(mtx__gui__MainWindow);
        menuBar->setObjectName("menuBar");
        menuBar->setGeometry(QRect(0, 0, 838, 30));
        menuGUI = new QMenu(menuBar);
        menuGUI->setObjectName("menuGUI");
        menuGUI->setTitle(QString::fromUtf8("MKVToolNix &GUI"));
        menuMerge = new QMenu(menuBar);
        menuMerge->setObjectName("menuMerge");
        menuMerge->setTitle(QString::fromUtf8("&Multiplexer"));
        menuMergeAll = new QMenu(menuMerge);
        menuMergeAll->setObjectName("menuMergeAll");
        menuMergeModifySelectedTracks = new QMenu(menuMerge);
        menuMergeModifySelectedTracks->setObjectName("menuMergeModifySelectedTracks");
        menuHeaderEditor = new QMenu(menuBar);
        menuHeaderEditor->setObjectName("menuHeaderEditor");
        menuHeaderEditor->setTitle(QString::fromUtf8("Header &editor"));
        menuHeaderEditorAll = new QMenu(menuHeaderEditor);
        menuHeaderEditorAll->setObjectName("menuHeaderEditorAll");
        menuHeaderEditorModifyTrack = new QMenu(menuHeaderEditor);
        menuHeaderEditorModifyTrack->setObjectName("menuHeaderEditorModifyTrack");
        menuChapterEditor = new QMenu(menuBar);
        menuChapterEditor->setObjectName("menuChapterEditor");
        menuChapterEditor->setTitle(QString::fromUtf8("&Chapter editor"));
        menuChapterEditorAll = new QMenu(menuChapterEditor);
        menuChapterEditorAll->setObjectName("menuChapterEditorAll");
        menuJobOutput = new QMenu(menuBar);
        menuJobOutput->setObjectName("menuJobOutput");
        menuJobOutput->setTitle(QString::fromUtf8("&Job output"));
        menuJobOutputAll = new QMenu(menuJobOutput);
        menuJobOutputAll->setObjectName("menuJobOutputAll");
        menuHelp = new QMenu(menuBar);
        menuHelp->setObjectName("menuHelp");
        menuHelp->setTitle(QString::fromUtf8("&Help"));
        menuJobQueue = new QMenu(menuBar);
        menuJobQueue->setObjectName("menuJobQueue");
        menuJobQueue->setTitle(QString::fromUtf8("&Job queue"));
        menuStopJobQueue = new QMenu(menuJobQueue);
        menuStopJobQueue->setObjectName("menuStopJobQueue");
        QIcon icon29(QIcon::fromTheme(QString::fromUtf8("media-playback-stop")));
        menuStopJobQueue->setIcon(icon29);
        menuWindow = new QMenu(menuBar);
        menuWindow->setObjectName("menuWindow");
        menuInfo = new QMenu(menuBar);
        menuInfo->setObjectName("menuInfo");
        menuDebugging = new QMenu(menuBar);
        menuDebugging->setObjectName("menuDebugging");
        menuDebugging->setTitle(QString::fromUtf8("&Debugging"));
        menuDebuggingMerge = new QMenu(menuDebugging);
        menuDebuggingMerge->setObjectName("menuDebuggingMerge");
        menuDebuggingMerge->setTitle(QString::fromUtf8("&Multiplexer"));
        mtx__gui__MainWindow->setMenuBar(menuBar);
        statusBar = new QStatusBar(mtx__gui__MainWindow);
        statusBar->setObjectName("statusBar");
        mtx__gui__MainWindow->setStatusBar(statusBar);

        menuBar->addAction(menuGUI->menuAction());
        menuBar->addAction(menuMerge->menuAction());
        menuBar->addAction(menuInfo->menuAction());
        menuBar->addAction(menuHeaderEditor->menuAction());
        menuBar->addAction(menuChapterEditor->menuAction());
        menuBar->addAction(menuJobQueue->menuAction());
        menuBar->addAction(menuJobOutput->menuAction());
        menuBar->addAction(menuWindow->menuAction());
        menuBar->addAction(menuHelp->menuAction());
        menuBar->addAction(menuDebugging->menuAction());
        menuGUI->addAction(actionGUIPreferences);
        menuGUI->addSeparator();
        menuGUI->addAction(actionGUIMergeTool);
        menuGUI->addAction(actionGUIExtractionTool);
        menuGUI->addAction(actionGUIInfoTool);
        menuGUI->addAction(actionGUIHeaderEditor);
        menuGUI->addAction(actionGUIChapterEditor);
        menuGUI->addAction(actionGUITagEditor);
        menuGUI->addAction(actionGUIJobQueue);
        menuGUI->addAction(actionGUIJobOutput);
        menuGUI->addSeparator();
        menuGUI->addAction(actionGUIExit);
        menuMerge->addAction(actionMergeNew);
        menuMerge->addAction(actionMergeOpen);
        menuMerge->addAction(actionMergeSave);
        menuMerge->addAction(actionMergeSaveAs);
        menuMerge->addAction(actionMergeSaveOptionFile);
        menuMerge->addSeparator();
        menuMerge->addAction(actionMergeSaveAllSingle);
        menuMerge->addAction(actionMergeSaveAllSingleAs);
        menuMerge->addSeparator();
        menuMerge->addAction(actionMergeClose);
        menuMerge->addSeparator();
        menuMerge->addAction(actionMergeStartMuxing);
        menuMerge->addAction(actionMergeAddToJobQueue);
        menuMerge->addSeparator();
        menuMerge->addAction(menuMergeAll->menuAction());
        menuMerge->addSeparator();
        menuMerge->addAction(actionMergeShowMkvmergeCommandLine);
        menuMerge->addSeparator();
        menuMerge->addAction(actionMergeAddFilesFromClipboard);
        menuMerge->addSeparator();
        menuMerge->addAction(actionMergeCopyFirstFileNameToTitle);
        menuMerge->addAction(actionMergeCopyOutputFileNameToTitle);
        menuMerge->addAction(actionMergeCopyTitleToOutputFileName);
        menuMerge->addSeparator();
        menuMerge->addAction(menuMergeModifySelectedTracks->menuAction());
        menuMergeAll->addAction(actionMergeSaveAll);
        menuMergeAll->addSeparator();
        menuMergeAll->addAction(actionMergeCloseAll);
        menuMergeAll->addSeparator();
        menuMergeAll->addAction(actionMergeStartMuxingAll);
        menuMergeAll->addAction(actionMergeAddAllToJobQueue);
        menuHeaderEditor->addAction(actionHeaderEditorOpen);
        menuHeaderEditor->addAction(actionHeaderEditorReload);
        menuHeaderEditor->addSeparator();
        menuHeaderEditor->addAction(menuHeaderEditorModifyTrack->menuAction());
        menuHeaderEditor->addSeparator();
        menuHeaderEditor->addAction(actionHeaderEditorValidate);
        menuHeaderEditor->addAction(actionHeaderEditorSave);
        menuHeaderEditor->addSeparator();
        menuHeaderEditor->addAction(actionHeaderEditorClose);
        menuHeaderEditor->addSeparator();
        menuHeaderEditor->addAction(menuHeaderEditorAll->menuAction());
        menuHeaderEditorAll->addAction(actionHeaderEditorSaveAll);
        menuHeaderEditorAll->addSeparator();
        menuHeaderEditorAll->addAction(actionHeaderEditorCloseAll);
        menuChapterEditor->addAction(actionChapterEditorNew);
        menuChapterEditor->addSeparator();
        menuChapterEditor->addAction(actionChapterEditorOpen);
        menuChapterEditor->addAction(actionChapterEditorAppend);
        menuChapterEditor->addAction(actionChapterEditorReload);
        menuChapterEditor->addSeparator();
        menuChapterEditor->addAction(actionChapterEditorSave);
        menuChapterEditor->addAction(actionChapterEditorSaveAsXml);
        menuChapterEditor->addAction(actionChapterEditorSaveToMatroska);
        menuChapterEditor->addSeparator();
        menuChapterEditor->addAction(actionChapterEditorClose);
        menuChapterEditor->addSeparator();
        menuChapterEditor->addAction(menuChapterEditorAll->menuAction());
        menuChapterEditor->addSeparator();
        menuChapterEditor->addAction(actionChapterEditorRemoveFromMatroska);
        menuChapterEditorAll->addAction(actionChapterEditorSaveAll);
        menuChapterEditorAll->addSeparator();
        menuChapterEditorAll->addAction(actionChapterEditorCloseAll);
        menuJobOutput->addAction(actionJobOutputSave);
        menuJobOutput->addSeparator();
        menuJobOutput->addAction(actionJobOutputClose);
        menuJobOutput->addSeparator();
        menuJobOutput->addAction(menuJobOutputAll->menuAction());
        menuJobOutputAll->addAction(actionJobOutputSaveAll);
        menuJobOutputAll->addSeparator();
        menuJobOutputAll->addAction(actionJobOutputCloseAll);
        menuHelp->addAction(actionHelpMkvmergeDocumentation);
        menuHelp->addAction(actionHelpForum);
        menuHelp->addAction(actionHelpFAQ);
        menuHelp->addAction(actionHelpKnownProblems);
        menuHelp->addAction(actionHelpReportBug);
        menuHelp->addAction(actionHelpSystemInformation);
        menuHelp->addSeparator();
        menuHelp->addAction(actionHelpCodeOfConduct);
        menuHelp->addSeparator();
        menuHelp->addAction(actionHelpWebSite);
        menuHelp->addSeparator();
        menuHelp->addAction(actionHelpCheckForUpdates);
        menuJobQueue->addAction(actionJobQueueStartAllPending);
        menuJobQueue->addSeparator();
        menuJobQueue->addAction(menuStopJobQueue->menuAction());
        menuJobQueue->addSeparator();
        menuJobQueue->addAction(actionJobQueueRemoveDoneOk);
        menuJobQueue->addAction(actionJobQueueRemoveDone);
        menuJobQueue->addAction(actionJobQueueRemoveAll);
        menuJobQueue->addSeparator();
        menuJobQueue->addAction(actionJobQueueAcknowledgeAllWarnings);
        menuJobQueue->addAction(actionJobQueueAcknowledgeAllErrors);
        menuJobQueue->addAction(actionJobQueueAcknowledgeAllWarningsErrors);
        menuStopJobQueue->addAction(actionJobQueueStopAfterCurrentJob);
        menuStopJobQueue->addAction(actionJobQueueStopImmediately);
        menuWindow->addAction(actionWindowNext);
        menuWindow->addAction(actionWindowPrevious);
        menuInfo->addAction(actionInfoOpen);
        menuInfo->addSeparator();
        menuInfo->addAction(actionInfoSave);
        menuInfo->addSeparator();
        menuInfo->addAction(actionInfoClose);
        menuInfo->addSeparator();
        menuInfo->addAction(actionInfoCloseAll);
        menuDebugging->addAction(menuDebuggingMerge->menuAction());
        menuDebuggingMerge->addAction(actionDbgMergeInputSetupHorizontalScrollAreaInputLayout);
        menuDebuggingMerge->addAction(actionDbgMergeInputSetupHorizontalTwoColumnsInputLayout);
        menuDebuggingMerge->addAction(actionDbgMergeInputSetupVerticalTabWidgetInputLayout);

        retranslateUi(mtx__gui__MainWindow);

        QMetaObject::connectSlotsByName(mtx__gui__MainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *mtx__gui__MainWindow)
    {
        actionMergeNew->setText(QTR("&New", nullptr));
#if QT_CONFIG(shortcut)
        actionMergeNew->setShortcut(QTR("Ctrl+N", nullptr));
#endif // QT_CONFIG(shortcut)
        actionMergeSave->setText(QTR("&Save settings", nullptr));
#if QT_CONFIG(shortcut)
        actionMergeSave->setShortcut(QTR("Ctrl+S", nullptr));
#endif // QT_CONFIG(shortcut)
        actionMergeOpen->setText(QTR("&Open settings", nullptr));
#if QT_CONFIG(shortcut)
        actionMergeOpen->setShortcut(QTR("Ctrl+O", nullptr));
#endif // QT_CONFIG(shortcut)
        actionMergeSaveAs->setText(QTR("Sa&ve settings as", nullptr));
        actionGUIExit->setText(QTR("E&xit", nullptr));
#if QT_CONFIG(shortcut)
        actionGUIExit->setShortcut(QTR("Ctrl+Q", nullptr));
#endif // QT_CONFIG(shortcut)
        actionMergeStartMuxing->setText(QTR("Start &multiplexing", nullptr));
#if QT_CONFIG(shortcut)
        actionMergeStartMuxing->setShortcut(QTR("Ctrl+R", nullptr));
#endif // QT_CONFIG(shortcut)
        actionMergeSaveOptionFile->setText(QTR("C&reate option file", nullptr));
        actionMergeShowMkvmergeCommandLine->setText(QTR("S&how command line", nullptr));
        actionMergeCopyCommandLineToClipboard->setText(QTR("&Copy command line to clipboard", nullptr));
        actionMergeAddToJobQueue->setText(QTR("Add to job &queue", nullptr));
        actionGUIPreferences->setText(QTR("&Preferences", nullptr));
#if QT_CONFIG(shortcut)
        actionGUIPreferences->setShortcut(QTR("Ctrl+P", nullptr));
#endif // QT_CONFIG(shortcut)
        actionHelpCheckForUpdates->setText(QTR("Check for &updates", nullptr));
        actionHelpCodeOfConduct->setText(QTR("&Code of Conduct", nullptr));
        actionHeaderEditorOpen->setText(QTR("&Open Matroska or WebM file", nullptr));
#if QT_CONFIG(shortcut)
        actionHeaderEditorOpen->setShortcut(QTR("Ctrl+O", nullptr));
#endif // QT_CONFIG(shortcut)
        actionHeaderEditorClose->setText(QTR("&Close", nullptr));
#if QT_CONFIG(shortcut)
        actionHeaderEditorClose->setShortcut(QTR("Ctrl+W", nullptr));
#endif // QT_CONFIG(shortcut)
        actionHeaderEditorSave->setText(QTR("&Save", nullptr));
#if QT_CONFIG(shortcut)
        actionHeaderEditorSave->setShortcut(QTR("Ctrl+S", nullptr));
#endif // QT_CONFIG(shortcut)
        actionHeaderEditorReload->setText(QTR("&Reload", nullptr));
        actionHeaderEditorValidate->setText(QTR("&Validate values", nullptr));
        actionChapterEditorNew->setText(QTR("&New", nullptr));
#if QT_CONFIG(shortcut)
        actionChapterEditorNew->setShortcut(QTR("Ctrl+N", nullptr));
#endif // QT_CONFIG(shortcut)
        actionChapterEditorOpen->setText(QTR("&Open supported chapter file format", nullptr));
#if QT_CONFIG(shortcut)
        actionChapterEditorOpen->setShortcut(QTR("Ctrl+O", nullptr));
#endif // QT_CONFIG(shortcut)
        actionChapterEditorAppend->setText(QTR("A&ppend chapters from supported file format", nullptr));
        actionChapterEditorClose->setText(QTR("&Close", nullptr));
#if QT_CONFIG(shortcut)
        actionChapterEditorClose->setShortcut(QTR("Ctrl+W", nullptr));
#endif // QT_CONFIG(shortcut)
        actionChapterEditorSave->setText(QTR("&Save", nullptr));
#if QT_CONFIG(shortcut)
        actionChapterEditorSave->setShortcut(QTR("Ctrl+S", nullptr));
#endif // QT_CONFIG(shortcut)
        actionChapterEditorSaveAsXml->setText(QTR("Save as &XML file", nullptr));
        actionChapterEditorSaveToMatroska->setText(QTR("Save to &Matroska or WebM file", nullptr));
        actionChapterEditorReload->setText(QTR("&Reload", nullptr));
        actionGUIMergeTool->setText(QTR("&Multiplexer", nullptr));
        actionGUIExtractionTool->setText(QTR("&Extraction tool", nullptr));
        actionGUIInfoTool->setText(QTR("&Info tool", nullptr));
        actionGUIHeaderEditor->setText(QTR("&Header editor", nullptr));
        actionGUIChapterEditor->setText(QTR("&Chapter editor", nullptr));
        actionGUIJobQueue->setText(QTR("&Job queue", nullptr));
        actionGUIJobOutput->setText(QTR("Job &output", nullptr));
        actionGUITagEditor->setText(QTR("&Tag editor", nullptr));
        actionMergeClose->setText(QTR("&Close", nullptr));
#if QT_CONFIG(shortcut)
        actionMergeClose->setShortcut(QTR("Ctrl+W", nullptr));
#endif // QT_CONFIG(shortcut)
        actionJobOutputSave->setText(QTR("&Save", nullptr));
#if QT_CONFIG(shortcut)
        actionJobOutputSave->setShortcut(QTR("Ctrl+S", nullptr));
#endif // QT_CONFIG(shortcut)
        actionJobOutputClose->setText(QTR("&Close", nullptr));
#if QT_CONFIG(shortcut)
        actionJobOutputClose->setShortcut(QTR("Ctrl+W", nullptr));
#endif // QT_CONFIG(shortcut)
        actionHelpWebSite->setText(QTR("MKVToolNix &web site", nullptr));
        actionHelpForum->setText(QTR("Community && &help forum", nullptr));
        actionHelpFAQ->setText(QTR("&FAQ", nullptr));
        actionHelpKnownProblems->setText(QTR("Known &problems in recent releases", nullptr));
        actionHelpReportBug->setText(QTR("Report a &bug", nullptr));
        actionHelpSystemInformation->setText(QTR("S&ystem information", nullptr));
        actionHelpMkvmergeDocumentation->setText(QTR("mkv&merge documentation", nullptr));
        actionJobQueueRemoveDoneOk->setText(QTR("Remove &successfully completed jobs", nullptr));
#if QT_CONFIG(shortcut)
        actionJobQueueRemoveDoneOk->setShortcut(QTR("Ctrl+L", nullptr));
#endif // QT_CONFIG(shortcut)
        actionJobQueueRemoveAll->setText(QTR("Remove a&ll jobs", nullptr));
        actionJobQueueAcknowledgeAllWarnings->setText(QTR("Acknowledge all &warnings", nullptr));
        actionJobQueueAcknowledgeAllErrors->setText(QTR("Acknowledge all &errors", nullptr));
        actionJobQueueAcknowledgeAllWarningsErrors->setText(QTR("Acknowledge &all warnings and errors", nullptr));
        actionJobQueueRemoveDone->setText(QTR("Remove &completed jobs", nullptr));
#if QT_CONFIG(shortcut)
        actionJobQueueRemoveDone->setShortcut(QTR("Ctrl+Shift+L", nullptr));
#endif // QT_CONFIG(shortcut)
        actionJobQueueStartAllPending->setText(QTR("Sta&rt all pending jobs", nullptr));
#if QT_CONFIG(shortcut)
        actionJobQueueStartAllPending->setShortcut(QTR("Ctrl+R", nullptr));
#endif // QT_CONFIG(shortcut)
        actionJobQueueStopAfterCurrentJob->setText(QTR("Stop &after all running jobs have finished", nullptr));
        actionJobQueueStopImmediately->setText(QTR("Abort all running jobs and stop &immediately", nullptr));
        actionMergeCopyFirstFileNameToTitle->setText(QTR("Copy &first source file's name to file title", nullptr));
#if QT_CONFIG(shortcut)
        actionMergeCopyFirstFileNameToTitle->setShortcut(QTR("Ctrl+F", nullptr));
#endif // QT_CONFIG(shortcut)
        actionMergeCopyOutputFileNameToTitle->setText(QTR("Copy &destination file's name to file title", nullptr));
#if QT_CONFIG(shortcut)
        actionMergeCopyOutputFileNameToTitle->setShortcut(QTR("Ctrl+D", nullptr));
#endif // QT_CONFIG(shortcut)
        actionMergeCopyTitleToOutputFileName->setText(QTR("Copy file &title to destination file name", nullptr));
#if QT_CONFIG(shortcut)
        actionMergeCopyTitleToOutputFileName->setShortcut(QTR("Ctrl+T", nullptr));
#endif // QT_CONFIG(shortcut)
        actionChapterEditorRemoveFromMatroska->setText(QTR("Remo&ve chapters from existing Matroska file", nullptr));
        actionChapterEditorCloseAll->setText(QTR("&Close", nullptr));
        actionChapterEditorSaveAll->setText(QTR("&Save", nullptr));
        actionHeaderEditorCloseAll->setText(QTR("&Close", nullptr));
        actionHeaderEditorSaveAll->setText(QTR("&Save", nullptr));
        actionMergeCloseAll->setText(QTR("&Close", nullptr));
        actionMergeSaveAll->setText(QTR("&Save settings", nullptr));
        actionMergeStartMuxingAll->setText(QTR("Start &multiplexing", nullptr));
        actionMergeAddAllToJobQueue->setText(QTR("Add to job &queue", nullptr));
        actionJobOutputCloseAll->setText(QTR("&Close", nullptr));
        actionJobOutputSaveAll->setText(QTR("&Save", nullptr));
#if QT_CONFIG(shortcut)
        actionWindowNext->setShortcut(QTR("Ctrl+F6", nullptr));
#endif // QT_CONFIG(shortcut)
#if QT_CONFIG(shortcut)
        actionWindowPrevious->setShortcut(QTR("Ctrl+Shift+F6", nullptr));
#endif // QT_CONFIG(shortcut)
        actionInfoOpen->setText(QTR("&Open Matroska or WebM file", nullptr));
#if QT_CONFIG(shortcut)
        actionInfoOpen->setShortcut(QTR("Ctrl+O", nullptr));
#endif // QT_CONFIG(shortcut)
        actionInfoClose->setText(QTR("&Close", nullptr));
#if QT_CONFIG(shortcut)
        actionInfoClose->setShortcut(QTR("Ctrl+W", nullptr));
#endif // QT_CONFIG(shortcut)
        actionInfoCloseAll->setText(QTR("Close &all tabs", nullptr));
        actionInfoSave->setText(QTR("&Save", nullptr));
#if QT_CONFIG(shortcut)
        actionInfoSave->setShortcut(QTR("Ctrl+S", nullptr));
#endif // QT_CONFIG(shortcut)
        actionMergeAddFilesFromClipboard->setText(QTR("Add files from clip&board", nullptr));
        actionMergeSaveAllSingle->setText(QTR("Save all settings to single file", nullptr));
#if QT_CONFIG(shortcut)
        actionMergeSaveAllSingle->setShortcut(QTR("Ctrl+Shift+S", nullptr));
#endif // QT_CONFIG(shortcut)
        actionMergeSaveAllSingleAs->setText(QTR("Save all settings to single file as", nullptr));
        menuMergeAll->setTitle(QTR("Actions for &all tabs", nullptr));
        menuMergeModifySelectedTracks->setTitle(QTR("Modif&y selected tracks", nullptr));
        menuHeaderEditorAll->setTitle(QTR("Actions for &all tabs", nullptr));
        menuHeaderEditorModifyTrack->setTitle(QTR("Modif&y selected track", nullptr));
        menuChapterEditorAll->setTitle(QTR("Actions for &all tabs", nullptr));
        menuJobOutputAll->setTitle(QTR("Actions for &all tabs", nullptr));
        menuStopJobQueue->setTitle(QTR("S&top job queue", nullptr));
        menuWindow->setTitle(QTR("&Window", nullptr));
        menuInfo->setTitle(QTR("&Info tool", nullptr));
        (void)mtx__gui__MainWindow;
    } // retranslateUi

};

} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Ui {
    class MainWindow: public Ui_MainWindow {};
} // namespace Ui
} // namespace gui
} // namespace mtx

#endif // MAIN_WINDOW_H
