/********************************************************************************
** Form generated from reading UI file 'select_playlist_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef SELECT_PLAYLIST_DIALOG_H
#define SELECT_PLAYLIST_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/merge/disc_library_information_widget.h"

namespace mtx {
namespace gui {
namespace Merge {

class Ui_SelectPlaylistDialog
{
public:
    QVBoxLayout *verticalLayout_5;
    QSplitter *selectPlaylistDialogSplitter3;
    QGroupBox *gbPlaylists;
    QVBoxLayout *verticalLayout_6;
    QSplitter *selectPlaylistDialogSplitter1;
    QWidget *layoutWidget1;
    QVBoxLayout *verticalLayout;
    QLabel *scannedFilesLabel;
    QFrame *line;
    QTreeWidget *scannedFiles;
    QWidget *layoutWidget2;
    QVBoxLayout *verticalLayout_4;
    QLabel *detailsLabel;
    QFrame *line_2;
    QGridLayout *gridLayout;
    QLabel *durationLabel;
    QLabel *duration;
    QLabel *sizeLabel;
    QLabel *numberOfChaptersLabel;
    QLabel *numberOfChapters;
    QLabel *size;
    QSplitter *selectPlaylistDialogSplitter2;
    QWidget *layoutWidget3;
    QVBoxLayout *verticalLayout_2;
    QLabel *tracksLabel;
    QTreeWidget *tracks;
    QWidget *layoutWidget4;
    QVBoxLayout *verticalLayout_3;
    QLabel *playlistItemsLabel;
    QTreeWidget *playlistItems;
    QGroupBox *gbDiscLibrary;
    QVBoxLayout *verticalLayout_9;
    QStackedWidget *discLibraryStack;
    QWidget *page;
    QVBoxLayout *verticalLayout_7;
    mtx::gui::Merge::DiscLibraryInformationWidget *discLibrary;
    QWidget *page_2;
    QVBoxLayout *verticalLayout_8;
    QLabel *noDiscLibraryInfoFound;
    QSpacerItem *noDiscLibraryInfoFoundSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *mtx__gui__Merge__SelectPlaylistDialog)
    {
        if (mtx__gui__Merge__SelectPlaylistDialog->objectName().isEmpty())
            mtx__gui__Merge__SelectPlaylistDialog->setObjectName("mtx__gui__Merge__SelectPlaylistDialog");
        mtx__gui__Merge__SelectPlaylistDialog->setWindowModality(Qt::ApplicationModal);
        mtx__gui__Merge__SelectPlaylistDialog->resize(1140, 641);
        verticalLayout_5 = new QVBoxLayout(mtx__gui__Merge__SelectPlaylistDialog);
        verticalLayout_5->setObjectName("verticalLayout_5");
        selectPlaylistDialogSplitter3 = new QSplitter(mtx__gui__Merge__SelectPlaylistDialog);
        selectPlaylistDialogSplitter3->setObjectName("selectPlaylistDialogSplitter3");
        selectPlaylistDialogSplitter3->setOrientation(Qt::Horizontal);
        gbPlaylists = new QGroupBox(selectPlaylistDialogSplitter3);
        gbPlaylists->setObjectName("gbPlaylists");
        verticalLayout_6 = new QVBoxLayout(gbPlaylists);
        verticalLayout_6->setObjectName("verticalLayout_6");
        selectPlaylistDialogSplitter1 = new QSplitter(gbPlaylists);
        selectPlaylistDialogSplitter1->setObjectName("selectPlaylistDialogSplitter1");
        selectPlaylistDialogSplitter1->setOrientation(Qt::Horizontal);
        layoutWidget1 = new QWidget(selectPlaylistDialogSplitter1);
        layoutWidget1->setObjectName("layoutWidget1");
        verticalLayout = new QVBoxLayout(layoutWidget1);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        scannedFilesLabel = new QLabel(layoutWidget1);
        scannedFilesLabel->setObjectName("scannedFilesLabel");

        verticalLayout->addWidget(scannedFilesLabel);

        line = new QFrame(layoutWidget1);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        scannedFiles = new QTreeWidget(layoutWidget1);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setTextAlignment(3, Qt::AlignTrailing|Qt::AlignVCenter);
        __qtreewidgetitem->setTextAlignment(2, Qt::AlignTrailing|Qt::AlignVCenter);
        __qtreewidgetitem->setTextAlignment(1, Qt::AlignTrailing|Qt::AlignVCenter);
        scannedFiles->setHeaderItem(__qtreewidgetitem);
        scannedFiles->setObjectName("scannedFiles");
        scannedFiles->setEditTriggers(QAbstractItemView::NoEditTriggers);
        scannedFiles->setProperty("showDropIndicator", QVariant(false));
        scannedFiles->setSelectionMode(QAbstractItemView::ExtendedSelection);

        verticalLayout->addWidget(scannedFiles);

        selectPlaylistDialogSplitter1->addWidget(layoutWidget1);
        layoutWidget2 = new QWidget(selectPlaylistDialogSplitter1);
        layoutWidget2->setObjectName("layoutWidget2");
        verticalLayout_4 = new QVBoxLayout(layoutWidget2);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        detailsLabel = new QLabel(layoutWidget2);
        detailsLabel->setObjectName("detailsLabel");

        verticalLayout_4->addWidget(detailsLabel);

        line_2 = new QFrame(layoutWidget2);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_4->addWidget(line_2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        durationLabel = new QLabel(layoutWidget2);
        durationLabel->setObjectName("durationLabel");

        gridLayout->addWidget(durationLabel, 0, 0, 1, 1);

        duration = new QLabel(layoutWidget2);
        duration->setObjectName("duration");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(duration->sizePolicy().hasHeightForWidth());
        duration->setSizePolicy(sizePolicy);

        gridLayout->addWidget(duration, 0, 1, 1, 1);

        sizeLabel = new QLabel(layoutWidget2);
        sizeLabel->setObjectName("sizeLabel");

        gridLayout->addWidget(sizeLabel, 1, 0, 1, 1);

        numberOfChaptersLabel = new QLabel(layoutWidget2);
        numberOfChaptersLabel->setObjectName("numberOfChaptersLabel");

        gridLayout->addWidget(numberOfChaptersLabel, 2, 0, 1, 1);

        numberOfChapters = new QLabel(layoutWidget2);
        numberOfChapters->setObjectName("numberOfChapters");
        sizePolicy.setHeightForWidth(numberOfChapters->sizePolicy().hasHeightForWidth());
        numberOfChapters->setSizePolicy(sizePolicy);

        gridLayout->addWidget(numberOfChapters, 2, 1, 1, 1);

        size = new QLabel(layoutWidget2);
        size->setObjectName("size");
        sizePolicy.setHeightForWidth(size->sizePolicy().hasHeightForWidth());
        size->setSizePolicy(sizePolicy);

        gridLayout->addWidget(size, 1, 1, 1, 1);


        verticalLayout_4->addLayout(gridLayout);

        selectPlaylistDialogSplitter2 = new QSplitter(layoutWidget2);
        selectPlaylistDialogSplitter2->setObjectName("selectPlaylistDialogSplitter2");
        selectPlaylistDialogSplitter2->setOrientation(Qt::Vertical);
        layoutWidget3 = new QWidget(selectPlaylistDialogSplitter2);
        layoutWidget3->setObjectName("layoutWidget3");
        verticalLayout_2 = new QVBoxLayout(layoutWidget3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        tracksLabel = new QLabel(layoutWidget3);
        tracksLabel->setObjectName("tracksLabel");

        verticalLayout_2->addWidget(tracksLabel);

        tracks = new QTreeWidget(layoutWidget3);
        QTreeWidgetItem *__qtreewidgetitem1 = new QTreeWidgetItem();
        __qtreewidgetitem1->setTextAlignment(0, Qt::AlignTrailing|Qt::AlignVCenter);
        tracks->setHeaderItem(__qtreewidgetitem1);
        tracks->setObjectName("tracks");
        tracks->setEditTriggers(QAbstractItemView::NoEditTriggers);
        tracks->setProperty("showDropIndicator", QVariant(false));
        tracks->setSelectionBehavior(QAbstractItemView::SelectRows);

        verticalLayout_2->addWidget(tracks);

        selectPlaylistDialogSplitter2->addWidget(layoutWidget3);
        layoutWidget4 = new QWidget(selectPlaylistDialogSplitter2);
        layoutWidget4->setObjectName("layoutWidget4");
        verticalLayout_3 = new QVBoxLayout(layoutWidget4);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        playlistItemsLabel = new QLabel(layoutWidget4);
        playlistItemsLabel->setObjectName("playlistItemsLabel");

        verticalLayout_3->addWidget(playlistItemsLabel);

        playlistItems = new QTreeWidget(layoutWidget4);
        playlistItems->setObjectName("playlistItems");
        playlistItems->setEditTriggers(QAbstractItemView::NoEditTriggers);
        playlistItems->setProperty("showDropIndicator", QVariant(false));
        playlistItems->setSelectionBehavior(QAbstractItemView::SelectRows);

        verticalLayout_3->addWidget(playlistItems);

        selectPlaylistDialogSplitter2->addWidget(layoutWidget4);

        verticalLayout_4->addWidget(selectPlaylistDialogSplitter2);

        selectPlaylistDialogSplitter1->addWidget(layoutWidget2);

        verticalLayout_6->addWidget(selectPlaylistDialogSplitter1);

        selectPlaylistDialogSplitter3->addWidget(gbPlaylists);
        gbDiscLibrary = new QGroupBox(selectPlaylistDialogSplitter3);
        gbDiscLibrary->setObjectName("gbDiscLibrary");
        verticalLayout_9 = new QVBoxLayout(gbDiscLibrary);
        verticalLayout_9->setObjectName("verticalLayout_9");
        verticalLayout_9->setContentsMargins(0, 0, 0, 0);
        discLibraryStack = new QStackedWidget(gbDiscLibrary);
        discLibraryStack->setObjectName("discLibraryStack");
        page = new QWidget();
        page->setObjectName("page");
        verticalLayout_7 = new QVBoxLayout(page);
        verticalLayout_7->setObjectName("verticalLayout_7");
        discLibrary = new mtx::gui::Merge::DiscLibraryInformationWidget(page);
        discLibrary->setObjectName("discLibrary");
        discLibrary->setEditTriggers(QAbstractItemView::NoEditTriggers);
        discLibrary->setProperty("showDropIndicator", QVariant(false));

        verticalLayout_7->addWidget(discLibrary);

        discLibraryStack->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        verticalLayout_8 = new QVBoxLayout(page_2);
        verticalLayout_8->setObjectName("verticalLayout_8");
        noDiscLibraryInfoFound = new QLabel(page_2);
        noDiscLibraryInfoFound->setObjectName("noDiscLibraryInfoFound");

        verticalLayout_8->addWidget(noDiscLibraryInfoFound);

        noDiscLibraryInfoFoundSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_8->addItem(noDiscLibraryInfoFoundSpacer);

        discLibraryStack->addWidget(page_2);

        verticalLayout_9->addWidget(discLibraryStack);

        selectPlaylistDialogSplitter3->addWidget(gbDiscLibrary);

        verticalLayout_5->addWidget(selectPlaylistDialogSplitter3);

        buttonBox = new QDialogButtonBox(mtx__gui__Merge__SelectPlaylistDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_5->addWidget(buttonBox);

        QWidget::setTabOrder(scannedFiles, tracks);
        QWidget::setTabOrder(tracks, playlistItems);
        QWidget::setTabOrder(playlistItems, buttonBox);

        retranslateUi(mtx__gui__Merge__SelectPlaylistDialog);

        discLibraryStack->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(mtx__gui__Merge__SelectPlaylistDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__Merge__SelectPlaylistDialog)
    {
        mtx__gui__Merge__SelectPlaylistDialog->setWindowTitle(QTR("Select file to add", nullptr));
        gbPlaylists->setTitle(QTR("Select one or more playlists to add", nullptr));
        scannedFilesLabel->setText(QTR("Scanned Files", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = scannedFiles->headerItem();
        ___qtreewidgetitem->setText(3, QTR("Size", nullptr));
        ___qtreewidgetitem->setText(2, QTR("Chapters", nullptr));
        ___qtreewidgetitem->setText(1, QTR("Duration", nullptr));
        ___qtreewidgetitem->setText(0, QTR("File name", nullptr));
        detailsLabel->setText(QTR("Details", nullptr));
        durationLabel->setText(QTR("Duration:", nullptr));
        duration->setText(QString());
        sizeLabel->setText(QTR("Size:", nullptr));
        numberOfChaptersLabel->setText(QTR("Number of chapters:", nullptr));
        numberOfChapters->setText(QString());
        size->setText(QString());
        tracksLabel->setText(QTR("Tracks:", nullptr));
        QTreeWidgetItem *___qtreewidgetitem1 = tracks->headerItem();
        ___qtreewidgetitem1->setText(4, QTR("Properties", nullptr));
        ___qtreewidgetitem1->setText(3, QTR("Language", nullptr));
        ___qtreewidgetitem1->setText(2, QTR("Codec", nullptr));
        ___qtreewidgetitem1->setText(1, QTR("Type", nullptr));
        ___qtreewidgetitem1->setText(0, QTR("ID", nullptr));
        playlistItemsLabel->setText(QTR("Playlist items:", nullptr));
        QTreeWidgetItem *___qtreewidgetitem2 = playlistItems->headerItem();
        ___qtreewidgetitem2->setText(2, QTR("Directory", nullptr));
        ___qtreewidgetitem2->setText(1, QTR("File name", nullptr));
        ___qtreewidgetitem2->setText(0, QTR("Order", nullptr));
        gbDiscLibrary->setTitle(QTR("Select disc library information to use", nullptr));
        QTreeWidgetItem *___qtreewidgetitem3 = discLibrary->headerItem();
        ___qtreewidgetitem3->setText(3, QTR("Size", nullptr));
        ___qtreewidgetitem3->setText(2, QTR("Cover image", nullptr));
        ___qtreewidgetitem3->setText(1, QTR("Title", nullptr));
        ___qtreewidgetitem3->setText(0, QTR("Language", nullptr));
        noDiscLibraryInfoFound->setText(QTR("No disc library information was found.", nullptr));
    } // retranslateUi

};

} // namespace Merge
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Merge {
namespace Ui {
    class SelectPlaylistDialog: public Ui_SelectPlaylistDialog {};
} // namespace Ui
} // namespace Merge
} // namespace gui
} // namespace mtx

#endif // SELECT_PLAYLIST_DIALOG_H
