/********************************************************************************
** Form generated from reading UI file 'text_display_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef TEXT_DISPLAY_DIALOG_H
#define TEXT_DISPLAY_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>

namespace mtx {
namespace gui {

class Ui_TextDisplayDialog
{
public:
    QVBoxLayout *verticalLayout;
    QTextBrowser *text;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *pbSave;
    QPushButton *pbCopyToClipboard;
    QPushButton *pbClose;

    void setupUi(QDialog *mtx__gui__TextDisplayDialog)
    {
        if (mtx__gui__TextDisplayDialog->objectName().isEmpty())
            mtx__gui__TextDisplayDialog->setObjectName("mtx__gui__TextDisplayDialog");
        mtx__gui__TextDisplayDialog->resize(629, 480);
        mtx__gui__TextDisplayDialog->setWindowTitle(QString::fromUtf8(""));
        verticalLayout = new QVBoxLayout(mtx__gui__TextDisplayDialog);
        verticalLayout->setObjectName("verticalLayout");
        text = new QTextBrowser(mtx__gui__TextDisplayDialog);
        text->setObjectName("text");
        text->setHtml(QString::fromUtf8("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Noto Sans'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:'Ubuntu';\"><br /></p></body></html>"));
        text->setTextInteractionFlags(Qt::LinksAccessibleByKeyboard|Qt::LinksAccessibleByMouse|Qt::TextBrowserInteraction|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);
        text->setOpenExternalLinks(true);

        verticalLayout->addWidget(text);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        pbSave = new QPushButton(mtx__gui__TextDisplayDialog);
        pbSave->setObjectName("pbSave");
        pbSave->setAutoDefault(false);

        horizontalLayout_2->addWidget(pbSave);

        pbCopyToClipboard = new QPushButton(mtx__gui__TextDisplayDialog);
        pbCopyToClipboard->setObjectName("pbCopyToClipboard");
        pbCopyToClipboard->setAutoDefault(false);

        horizontalLayout_2->addWidget(pbCopyToClipboard);

        pbClose = new QPushButton(mtx__gui__TextDisplayDialog);
        pbClose->setObjectName("pbClose");

        horizontalLayout_2->addWidget(pbClose);


        verticalLayout->addLayout(horizontalLayout_2);


        retranslateUi(mtx__gui__TextDisplayDialog);

        QMetaObject::connectSlotsByName(mtx__gui__TextDisplayDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__TextDisplayDialog)
    {
        pbSave->setText(QTR("&Save", nullptr));
        pbCopyToClipboard->setText(QTR("C&opy to clipboard", nullptr));
        pbClose->setText(QTR("&Close", nullptr));
        (void)mtx__gui__TextDisplayDialog;
    } // retranslateUi

};

} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Ui {
    class TextDisplayDialog: public Ui_TextDisplayDialog {};
} // namespace Ui
} // namespace gui
} // namespace mtx

#endif // TEXT_DISPLAY_DIALOG_H
