/********************************************************************************
** Form generated from reading UI file 'tool.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef TOOL_H
#define TOOL_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/util/basic_tree_view.h"

namespace mtx {
namespace gui {
namespace Jobs {

class Ui_Tool
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *jobQueueLabel;
    QFrame *line;
    QHBoxLayout *horizontalLayout;
    mtx::gui::Util::BasicTreeView *jobs;
    QWidget *moveJobsButtons;
    QVBoxLayout *verticalLayout_1;
    QPushButton *moveJobsUp;
    QPushButton *moveJobsDown;
    QSpacerItem *verticalSpacer_1;

    void setupUi(QWidget *mtx__gui__Jobs__Tool)
    {
        if (mtx__gui__Jobs__Tool->objectName().isEmpty())
            mtx__gui__Jobs__Tool->setObjectName("mtx__gui__Jobs__Tool");
        mtx__gui__Jobs__Tool->resize(898, 533);
        mtx__gui__Jobs__Tool->setAcceptDrops(true);
        mtx__gui__Jobs__Tool->setWindowTitle(QString::fromUtf8("mtx::gui::Jobs::Tool"));
        verticalLayout = new QVBoxLayout(mtx__gui__Jobs__Tool);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(-1, -1, -1, 0);
        jobQueueLabel = new QLabel(mtx__gui__Jobs__Tool);
        jobQueueLabel->setObjectName("jobQueueLabel");

        verticalLayout->addWidget(jobQueueLabel);

        line = new QFrame(mtx__gui__Jobs__Tool);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        jobs = new mtx::gui::Util::BasicTreeView(mtx__gui__Jobs__Tool);
        jobs->setObjectName("jobs");
        jobs->setContextMenuPolicy(Qt::CustomContextMenu);
        jobs->setAcceptDrops(true);
        jobs->setEditTriggers(QAbstractItemView::NoEditTriggers);
        jobs->setDragEnabled(true);
        jobs->setDragDropMode(QAbstractItemView::InternalMove);
        jobs->setDefaultDropAction(Qt::MoveAction);
        jobs->setSelectionMode(QAbstractItemView::ExtendedSelection);
        jobs->setSelectionBehavior(QAbstractItemView::SelectRows);

        horizontalLayout->addWidget(jobs);

        moveJobsButtons = new QWidget(mtx__gui__Jobs__Tool);
        moveJobsButtons->setObjectName("moveJobsButtons");
        verticalLayout_1 = new QVBoxLayout(moveJobsButtons);
        verticalLayout_1->setSpacing(6);
        verticalLayout_1->setContentsMargins(11, 11, 11, 11);
        verticalLayout_1->setObjectName("verticalLayout_1");
        verticalLayout_1->setContentsMargins(0, 0, 0, 0);
        moveJobsUp = new QPushButton(moveJobsButtons);
        moveJobsUp->setObjectName("moveJobsUp");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("arrow-up")));
        moveJobsUp->setIcon(icon);

        verticalLayout_1->addWidget(moveJobsUp);

        moveJobsDown = new QPushButton(moveJobsButtons);
        moveJobsDown->setObjectName("moveJobsDown");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("arrow-down")));
        moveJobsDown->setIcon(icon1);

        verticalLayout_1->addWidget(moveJobsDown);

        verticalSpacer_1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_1->addItem(verticalSpacer_1);


        horizontalLayout->addWidget(moveJobsButtons);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(mtx__gui__Jobs__Tool);

        QMetaObject::connectSlotsByName(mtx__gui__Jobs__Tool);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__Jobs__Tool)
    {
        jobQueueLabel->setText(QTR("Job queue", nullptr));
        moveJobsUp->setText(QString());
        moveJobsDown->setText(QString());
        (void)mtx__gui__Jobs__Tool;
    } // retranslateUi

};

} // namespace Jobs
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Jobs {
namespace Ui {
    class Tool: public Ui_Tool {};
} // namespace Ui
} // namespace Jobs
} // namespace gui
} // namespace mtx

#endif // TOOL_H
