/********************************************************************************
** Form generated from reading UI file 'job_settings_widget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef JOB_SETTINGS_WIDGET_H
#define JOB_SETTINGS_WIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/util/basic_line_edit.h"

namespace mtx {
namespace gui {
namespace Info {

class Ui_JobSettingsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *modeLabel;
    QComboBox *mode;
    QLabel *verbosityLabel;
    QComboBox *verbosity;
    QLabel *hexDumpsLabel;
    QComboBox *hexDumps;
    QLabel *fileNameLabel;
    QHBoxLayout *horizontalLayout;
    mtx::gui::Util::BasicLineEdit *fileName;
    QPushButton *browseFileName;
    QCheckBox *checksums;
    QCheckBox *trackInfo;
    QCheckBox *hexPositions;

    void setupUi(QWidget *mtx__gui__Info__JobSettingsWidget)
    {
        if (mtx__gui__Info__JobSettingsWidget->objectName().isEmpty())
            mtx__gui__Info__JobSettingsWidget->setObjectName("mtx__gui__Info__JobSettingsWidget");
        mtx__gui__Info__JobSettingsWidget->resize(538, 234);
        mtx__gui__Info__JobSettingsWidget->setWindowTitle(QString::fromUtf8("Form"));
        verticalLayout = new QVBoxLayout(mtx__gui__Info__JobSettingsWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        modeLabel = new QLabel(mtx__gui__Info__JobSettingsWidget);
        modeLabel->setObjectName("modeLabel");

        gridLayout->addWidget(modeLabel, 1, 0, 1, 1);

        mode = new QComboBox(mtx__gui__Info__JobSettingsWidget);
        mode->addItem(QString());
        mode->addItem(QString());
        mode->setObjectName("mode");

        gridLayout->addWidget(mode, 1, 1, 1, 1);

        verbosityLabel = new QLabel(mtx__gui__Info__JobSettingsWidget);
        verbosityLabel->setObjectName("verbosityLabel");

        gridLayout->addWidget(verbosityLabel, 2, 0, 1, 1);

        verbosity = new QComboBox(mtx__gui__Info__JobSettingsWidget);
        verbosity->addItem(QString());
        verbosity->addItem(QString());
        verbosity->setObjectName("verbosity");

        gridLayout->addWidget(verbosity, 2, 1, 1, 1);

        hexDumpsLabel = new QLabel(mtx__gui__Info__JobSettingsWidget);
        hexDumpsLabel->setObjectName("hexDumpsLabel");

        gridLayout->addWidget(hexDumpsLabel, 3, 0, 1, 1);

        hexDumps = new QComboBox(mtx__gui__Info__JobSettingsWidget);
        hexDumps->addItem(QString());
        hexDumps->addItem(QString());
        hexDumps->addItem(QString());
        hexDumps->setObjectName("hexDumps");

        gridLayout->addWidget(hexDumps, 3, 1, 1, 1);

        fileNameLabel = new QLabel(mtx__gui__Info__JobSettingsWidget);
        fileNameLabel->setObjectName("fileNameLabel");

        gridLayout->addWidget(fileNameLabel, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        fileName = new mtx::gui::Util::BasicLineEdit(mtx__gui__Info__JobSettingsWidget);
        fileName->setObjectName("fileName");

        horizontalLayout->addWidget(fileName);

        browseFileName = new QPushButton(mtx__gui__Info__JobSettingsWidget);
        browseFileName->setObjectName("browseFileName");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-open")));
        browseFileName->setIcon(icon);

        horizontalLayout->addWidget(browseFileName);


        gridLayout->addLayout(horizontalLayout, 0, 1, 1, 1);

        gridLayout->setColumnStretch(1, 1);

        verticalLayout->addLayout(gridLayout);

        checksums = new QCheckBox(mtx__gui__Info__JobSettingsWidget);
        checksums->setObjectName("checksums");

        verticalLayout->addWidget(checksums);

        trackInfo = new QCheckBox(mtx__gui__Info__JobSettingsWidget);
        trackInfo->setObjectName("trackInfo");

        verticalLayout->addWidget(trackInfo);

        hexPositions = new QCheckBox(mtx__gui__Info__JobSettingsWidget);
        hexPositions->setObjectName("hexPositions");

        verticalLayout->addWidget(hexPositions);

#if QT_CONFIG(shortcut)
        modeLabel->setBuddy(mode);
        verbosityLabel->setBuddy(verbosity);
        hexDumpsLabel->setBuddy(hexDumps);
        fileNameLabel->setBuddy(fileName);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(fileName, browseFileName);
        QWidget::setTabOrder(browseFileName, mode);
        QWidget::setTabOrder(mode, verbosity);
        QWidget::setTabOrder(verbosity, hexDumps);
        QWidget::setTabOrder(hexDumps, checksums);
        QWidget::setTabOrder(checksums, trackInfo);
        QWidget::setTabOrder(trackInfo, hexPositions);

        retranslateUi(mtx__gui__Info__JobSettingsWidget);

        QMetaObject::connectSlotsByName(mtx__gui__Info__JobSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__Info__JobSettingsWidget)
    {
        modeLabel->setText(QTR("&Mode:", nullptr));
        mode->setItemText(0, QTR("All elements in a tree-like structure", nullptr));
        mode->setItemText(1, QTR("One-line summaries for each track and frame", nullptr));

        verbosityLabel->setText(QTR("&Verbosity:", nullptr));
        verbosity->setItemText(0, QTR("Stop at the first cluster", nullptr));
        verbosity->setItemText(1, QTR("Show all elements", nullptr));

        hexDumpsLabel->setText(QTR("&Hex dumps:", nullptr));
        hexDumps->setItemText(0, QTR("Do not show hex dumps", nullptr));
        hexDumps->setItemText(1, QTR("Show first 16 bytes of frames and CodecPrivate elements as hex dumps", nullptr));
        hexDumps->setItemText(2, QTR("Show all bytes of frames and CodecPrivate elements as hex dumps", nullptr));

        fileNameLabel->setText(QTR("&File name:", nullptr));
        browseFileName->setText(QString());
        checksums->setText(QTR("Calculate Adler-32 &checksums for each frame and binary element", nullptr));
        trackInfo->setText(QTR("Show a &summary line with statistics for each track at the end", nullptr));
        hexPositions->setText(QTR("Output element positions in he&xadecimal", nullptr));
        (void)mtx__gui__Info__JobSettingsWidget;
    } // retranslateUi

};

} // namespace Info
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Info {
namespace Ui {
    class JobSettingsWidget: public Ui_JobSettingsWidget {};
} // namespace Ui
} // namespace Info
} // namespace gui
} // namespace mtx

#endif // JOB_SETTINGS_WIDGET_H
