/********************************************************************************
** Form generated from reading UI file 'adding_appending_files_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef ADDING_APPENDING_FILES_DIALOG_H
#define ADDING_APPENDING_FILES_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

namespace mtx {
namespace gui {
namespace Merge {

class Ui_AddingAppendingFilesDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *lTitle;
    QFrame *line;
    QLabel *lQuestion;
    QRadioButton *rbAdd;
    QRadioButton *rbAddToNew;
    QRadioButton *rbAddEachToNew;
    QRadioButton *rbAppend;
    QRadioButton *rbAddAdditionalParts;
    QLabel *lAppendTo;
    QComboBox *cbFileName;
    QCheckBox *cbAlwaysCreateNewSettingsForVideoFiles;
    QFrame *line_2;
    QCheckBox *cbAlwaysUseThisDecision;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *mtx__gui__Merge__AddingAppendingFilesDialog)
    {
        if (mtx__gui__Merge__AddingAppendingFilesDialog->objectName().isEmpty())
            mtx__gui__Merge__AddingAppendingFilesDialog->setObjectName("mtx__gui__Merge__AddingAppendingFilesDialog");
        mtx__gui__Merge__AddingAppendingFilesDialog->resize(571, 384);
        verticalLayout = new QVBoxLayout(mtx__gui__Merge__AddingAppendingFilesDialog);
        verticalLayout->setObjectName("verticalLayout");
        lTitle = new QLabel(mtx__gui__Merge__AddingAppendingFilesDialog);
        lTitle->setObjectName("lTitle");
        lTitle->setWordWrap(true);

        verticalLayout->addWidget(lTitle);

        line = new QFrame(mtx__gui__Merge__AddingAppendingFilesDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        lQuestion = new QLabel(mtx__gui__Merge__AddingAppendingFilesDialog);
        lQuestion->setObjectName("lQuestion");
        lQuestion->setWordWrap(true);

        verticalLayout->addWidget(lQuestion);

        rbAdd = new QRadioButton(mtx__gui__Merge__AddingAppendingFilesDialog);
        rbAdd->setObjectName("rbAdd");

        verticalLayout->addWidget(rbAdd);

        rbAddToNew = new QRadioButton(mtx__gui__Merge__AddingAppendingFilesDialog);
        rbAddToNew->setObjectName("rbAddToNew");

        verticalLayout->addWidget(rbAddToNew);

        rbAddEachToNew = new QRadioButton(mtx__gui__Merge__AddingAppendingFilesDialog);
        rbAddEachToNew->setObjectName("rbAddEachToNew");

        verticalLayout->addWidget(rbAddEachToNew);

        rbAppend = new QRadioButton(mtx__gui__Merge__AddingAppendingFilesDialog);
        rbAppend->setObjectName("rbAppend");

        verticalLayout->addWidget(rbAppend);

        rbAddAdditionalParts = new QRadioButton(mtx__gui__Merge__AddingAppendingFilesDialog);
        rbAddAdditionalParts->setObjectName("rbAddAdditionalParts");

        verticalLayout->addWidget(rbAddAdditionalParts);

        lAppendTo = new QLabel(mtx__gui__Merge__AddingAppendingFilesDialog);
        lAppendTo->setObjectName("lAppendTo");
        lAppendTo->setWordWrap(true);

        verticalLayout->addWidget(lAppendTo);

        cbFileName = new QComboBox(mtx__gui__Merge__AddingAppendingFilesDialog);
        cbFileName->setObjectName("cbFileName");

        verticalLayout->addWidget(cbFileName);

        cbAlwaysCreateNewSettingsForVideoFiles = new QCheckBox(mtx__gui__Merge__AddingAppendingFilesDialog);
        cbAlwaysCreateNewSettingsForVideoFiles->setObjectName("cbAlwaysCreateNewSettingsForVideoFiles");

        verticalLayout->addWidget(cbAlwaysCreateNewSettingsForVideoFiles);

        line_2 = new QFrame(mtx__gui__Merge__AddingAppendingFilesDialog);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line_2);

        cbAlwaysUseThisDecision = new QCheckBox(mtx__gui__Merge__AddingAppendingFilesDialog);
        cbAlwaysUseThisDecision->setObjectName("cbAlwaysUseThisDecision");

        verticalLayout->addWidget(cbAlwaysUseThisDecision);

        verticalSpacer = new QSpacerItem(20, 14, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        buttonBox = new QDialogButtonBox(mtx__gui__Merge__AddingAppendingFilesDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout);

        QWidget::setTabOrder(rbAdd, rbAddToNew);
        QWidget::setTabOrder(rbAddToNew, rbAddEachToNew);
        QWidget::setTabOrder(rbAddEachToNew, rbAppend);
        QWidget::setTabOrder(rbAppend, rbAddAdditionalParts);
        QWidget::setTabOrder(rbAddAdditionalParts, cbFileName);
        QWidget::setTabOrder(cbFileName, cbAlwaysCreateNewSettingsForVideoFiles);
        QWidget::setTabOrder(cbAlwaysCreateNewSettingsForVideoFiles, cbAlwaysUseThisDecision);

        retranslateUi(mtx__gui__Merge__AddingAppendingFilesDialog);

        QMetaObject::connectSlotsByName(mtx__gui__Merge__AddingAppendingFilesDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__Merge__AddingAppendingFilesDialog)
    {
        mtx__gui__Merge__AddingAppendingFilesDialog->setWindowTitle(QTR("Adding files via drag & drop or copy & paste", nullptr));
        lTitle->setText(QTR("Adding files via drag & drop or copy & paste", nullptr));
        lQuestion->setText(QTR("What do you want to do with the files you've dragged & dropped or copied & pasted here?", nullptr));
        rbAdd->setText(QTR("Add as new source fi&les to the current multiplex settings", nullptr));
        rbAddToNew->setText(QTR("Create new &multiplex settings and add to those", nullptr));
        rbAddEachToNew->setText(QTR("Create new multiplex settings for &each file", nullptr));
        rbAppend->setText(QTR("Append to an e&xisting source file", nullptr));
        rbAddAdditionalParts->setText(QTR("Add as additional &parts to an existing source file", nullptr));
        lAppendTo->setText(QTR("If you want to append or add them as additional parts you have to select which source file to append or add them to:", nullptr));
        cbAlwaysCreateNewSettingsForVideoFiles->setText(QTR("Alwa&ys create new mutliplex settings for files containing video tracks", nullptr));
        cbAlwaysUseThisDecision->setText(QTR("Alwa&ys use the action selected above and don't ask again", nullptr));
    } // retranslateUi

};

} // namespace Merge
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Merge {
namespace Ui {
    class AddingAppendingFilesDialog: public Ui_AddingAppendingFilesDialog {};
} // namespace Ui
} // namespace Merge
} // namespace gui
} // namespace mtx

#endif // ADDING_APPENDING_FILES_DIALOG_H
