/********************************************************************************
** Form generated from reading UI file 'tool.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef TOOL_H
#define TOOL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/util/basic_tab_widget.h"

namespace mtx {
namespace gui {
namespace WatchJobs {

class Ui_Tool
{
public:
    QVBoxLayout *verticalLayout;
    mtx::gui::Util::BasicTabWidget *widgets;

    void setupUi(QWidget *mtx__gui__WatchJobs__Tool)
    {
        if (mtx__gui__WatchJobs__Tool->objectName().isEmpty())
            mtx__gui__WatchJobs__Tool->setObjectName("mtx__gui__WatchJobs__Tool");
        mtx__gui__WatchJobs__Tool->resize(742, 455);
        mtx__gui__WatchJobs__Tool->setWindowTitle(QString::fromUtf8("Form"));
        verticalLayout = new QVBoxLayout(mtx__gui__WatchJobs__Tool);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(-1, -1, -1, 0);
        widgets = new mtx::gui::Util::BasicTabWidget(mtx__gui__WatchJobs__Tool);
        widgets->setObjectName("widgets");
        widgets->setTabsClosable(true);

        verticalLayout->addWidget(widgets);


        retranslateUi(mtx__gui__WatchJobs__Tool);

        widgets->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(mtx__gui__WatchJobs__Tool);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__WatchJobs__Tool)
    {
        (void)mtx__gui__WatchJobs__Tool;
    } // retranslateUi

};

} // namespace WatchJobs
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace WatchJobs {
namespace Ui {
    class Tool: public Ui_Tool {};
} // namespace Ui
} // namespace WatchJobs
} // namespace gui
} // namespace mtx

#endif // TOOL_H
