/********************************************************************************
** Form generated from reading UI file 'tool.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef TOOL_H
#define TOOL_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/util/basic_tab_widget.h"

namespace mtx {
namespace gui {
namespace ChapterEditor {

class Ui_Tool
{
public:
    QVBoxLayout *verticalLayout_3;
    QStackedWidget *stack;
    QWidget *noFilesPage;
    QVBoxLayout *verticalLayout_2;
    QWidget *noFileOpened;
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QLabel *noFileOpenedLabel;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_2;
    QLabel *howToOpenLabel;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer_5;
    QPushButton *newFileButton;
    QSpacerItem *horizontalSpacer_6;
    QPushButton *openFileButton;
    QSpacerItem *horizontalSpacer_7;
    QSpacerItem *verticalSpacer_2;
    QWidget *editorsPage;
    QVBoxLayout *verticalLayout_4;
    mtx::gui::Util::BasicTabWidget *editors;

    void setupUi(QWidget *mtx__gui__ChapterEditor__Tool)
    {
        if (mtx__gui__ChapterEditor__Tool->objectName().isEmpty())
            mtx__gui__ChapterEditor__Tool->setObjectName("mtx__gui__ChapterEditor__Tool");
        mtx__gui__ChapterEditor__Tool->resize(910, 491);
        mtx__gui__ChapterEditor__Tool->setAcceptDrops(true);
        mtx__gui__ChapterEditor__Tool->setWindowTitle(QString::fromUtf8("Form"));
        verticalLayout_3 = new QVBoxLayout(mtx__gui__ChapterEditor__Tool);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(-1, -1, -1, 0);
        stack = new QStackedWidget(mtx__gui__ChapterEditor__Tool);
        stack->setObjectName("stack");
        noFilesPage = new QWidget();
        noFilesPage->setObjectName("noFilesPage");
        verticalLayout_2 = new QVBoxLayout(noFilesPage);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        noFileOpened = new QWidget(noFilesPage);
        noFileOpened->setObjectName("noFileOpened");
        verticalLayout = new QVBoxLayout(noFileOpened);
        verticalLayout->setObjectName("verticalLayout");
        verticalSpacer = new QSpacerItem(20, 74, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        noFileOpenedLabel = new QLabel(noFileOpened);
        noFileOpenedLabel->setObjectName("noFileOpenedLabel");

        horizontalLayout->addWidget(noFileOpenedLabel);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        howToOpenLabel = new QLabel(noFileOpened);
        howToOpenLabel->setObjectName("howToOpenLabel");

        horizontalLayout_2->addWidget(howToOpenLabel);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);


        verticalLayout->addLayout(horizontalLayout_2);

        verticalSpacer_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_3);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_5);

        newFileButton = new QPushButton(noFileOpened);
        newFileButton->setObjectName("newFileButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-new")));
        newFileButton->setIcon(icon);

        horizontalLayout_3->addWidget(newFileButton);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_6);

        openFileButton = new QPushButton(noFileOpened);
        openFileButton->setObjectName("openFileButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("document-open")));
        openFileButton->setIcon(icon1);

        horizontalLayout_3->addWidget(openFileButton);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_7);


        verticalLayout->addLayout(horizontalLayout_3);

        verticalSpacer_2 = new QSpacerItem(20, 73, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);


        verticalLayout_2->addWidget(noFileOpened);

        stack->addWidget(noFilesPage);
        editorsPage = new QWidget();
        editorsPage->setObjectName("editorsPage");
        verticalLayout_4 = new QVBoxLayout(editorsPage);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        editors = new mtx::gui::Util::BasicTabWidget(editorsPage);
        editors->setObjectName("editors");
        editors->setElideMode(Qt::ElideMiddle);
        editors->setTabsClosable(true);
        editors->setMovable(true);

        verticalLayout_4->addWidget(editors);

        stack->addWidget(editorsPage);

        verticalLayout_3->addWidget(stack);


        retranslateUi(mtx__gui__ChapterEditor__Tool);

        stack->setCurrentIndex(1);
        editors->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(mtx__gui__ChapterEditor__Tool);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__ChapterEditor__Tool)
    {
        noFileOpenedLabel->setText(QTR("No file has been opened yet.", nullptr));
        howToOpenLabel->setText(QTR("Open a file via the \"chapter editor\" menu, the buttons below or drag & drop one here.", nullptr));
        newFileButton->setText(QTR("&New", nullptr));
        openFileButton->setText(QTR("&Open supported chapter file format", nullptr));
        (void)mtx__gui__ChapterEditor__Tool;
    } // retranslateUi

};

} // namespace ChapterEditor
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace ChapterEditor {
namespace Ui {
    class Tool: public Ui_Tool {};
} // namespace Ui
} // namespace ChapterEditor
} // namespace gui
} // namespace mtx

#endif // TOOL_H
