/********************************************************************************
** Form generated from reading UI file 'tool.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef TOOL_H
#define TOOL_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/util/basic_tab_widget.h"

namespace mtx {
namespace gui {
namespace Merge {

class Ui_Tool
{
public:
    QVBoxLayout *verticalLayout_3;
    QWidget *overlordWidget;
    QHBoxLayout *horizontalLayout_5;
    QStackedWidget *stack;
    QWidget *noMergesPage;
    QVBoxLayout *verticalLayout_2;
    QWidget *noFileOpened;
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QLabel *noFileOpenedLabel;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_2;
    QLabel *howToOpenLabel;
    QSpacerItem *horizontalSpacer_4;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_9;
    QLabel *label;
    QSpacerItem *horizontalSpacer_8;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer_5;
    QPushButton *newFileButton;
    QSpacerItem *horizontalSpacer_6;
    QPushButton *openFileButton;
    QSpacerItem *horizontalSpacer_7;
    QSpacerItem *verticalSpacer_2;
    QWidget *mergesPage;
    QVBoxLayout *verticalLayout_4;
    mtx::gui::Util::BasicTabWidget *merges;
    QGroupBox *gbDragAndDrop;
    QVBoxLayout *verticalLayout_10;
    QWidget *wDNDFilesAllCurrent;
    QVBoxLayout *verticalLayout_5;
    QSpacerItem *verticalSpacer_4;
    QLabel *lDNDFilesAllCurrent;
    QSpacerItem *verticalSpacer_5;
    QFrame *line;
    QWidget *wDNDFilesAllOneNew;
    QVBoxLayout *verticalLayout_6;
    QSpacerItem *verticalSpacer_6;
    QLabel *lDNDFilesAllOneNew;
    QSpacerItem *verticalSpacer_7;
    QFrame *line_2;
    QWidget *wDNDFilesOneNewPerFile;
    QVBoxLayout *verticalLayout_7;
    QSpacerItem *verticalSpacer_8;
    QLabel *lDNDFilesOneNewPerFile;
    QSpacerItem *verticalSpacer_9;
    QFrame *line_3;
    QWidget *wDNDAttachmentsCover;
    QVBoxLayout *verticalLayout_8;
    QSpacerItem *verticalSpacer_10;
    QLabel *lDNDAttachmentsCover;
    QSpacerItem *verticalSpacer_11;
    QFrame *line_4;
    QWidget *wDNDAttachments;
    QVBoxLayout *verticalLayout_9;
    QSpacerItem *verticalSpacer_12;
    QLabel *lDNDAttachments;
    QSpacerItem *verticalSpacer_13;

    void setupUi(QWidget *mtx__gui__Merge__Tool)
    {
        if (mtx__gui__Merge__Tool->objectName().isEmpty())
            mtx__gui__Merge__Tool->setObjectName("mtx__gui__Merge__Tool");
        mtx__gui__Merge__Tool->resize(910, 491);
        mtx__gui__Merge__Tool->setAcceptDrops(true);
        mtx__gui__Merge__Tool->setWindowTitle(QString::fromUtf8("Form"));
        verticalLayout_3 = new QVBoxLayout(mtx__gui__Merge__Tool);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(-1, -1, -1, 0);
        overlordWidget = new QWidget(mtx__gui__Merge__Tool);
        overlordWidget->setObjectName("overlordWidget");
        horizontalLayout_5 = new QHBoxLayout(overlordWidget);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        stack = new QStackedWidget(overlordWidget);
        stack->setObjectName("stack");
        noMergesPage = new QWidget();
        noMergesPage->setObjectName("noMergesPage");
        verticalLayout_2 = new QVBoxLayout(noMergesPage);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        noFileOpened = new QWidget(noMergesPage);
        noFileOpened->setObjectName("noFileOpened");
        verticalLayout = new QVBoxLayout(noFileOpened);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalSpacer = new QSpacerItem(20, 74, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        noFileOpenedLabel = new QLabel(noFileOpened);
        noFileOpenedLabel->setObjectName("noFileOpenedLabel");

        horizontalLayout->addWidget(noFileOpenedLabel);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        howToOpenLabel = new QLabel(noFileOpened);
        howToOpenLabel->setObjectName("howToOpenLabel");

        horizontalLayout_2->addWidget(howToOpenLabel);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer_9 = new QSpacerItem(37, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_9);

        label = new QLabel(noFileOpened);
        label->setObjectName("label");

        horizontalLayout_4->addWidget(label);

        horizontalSpacer_8 = new QSpacerItem(37, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_8);


        verticalLayout->addLayout(horizontalLayout_4);

        verticalSpacer_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_3);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_5);

        newFileButton = new QPushButton(noFileOpened);
        newFileButton->setObjectName("newFileButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-new")));
        newFileButton->setIcon(icon);

        horizontalLayout_3->addWidget(newFileButton);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_6);

        openFileButton = new QPushButton(noFileOpened);
        openFileButton->setObjectName("openFileButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("document-open")));
        openFileButton->setIcon(icon1);

        horizontalLayout_3->addWidget(openFileButton);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_7);


        verticalLayout->addLayout(horizontalLayout_3);

        verticalSpacer_2 = new QSpacerItem(20, 73, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);


        verticalLayout_2->addWidget(noFileOpened);

        stack->addWidget(noMergesPage);
        mergesPage = new QWidget();
        mergesPage->setObjectName("mergesPage");
        verticalLayout_4 = new QVBoxLayout(mergesPage);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        merges = new mtx::gui::Util::BasicTabWidget(mergesPage);
        merges->setObjectName("merges");
        merges->setTabsClosable(true);
        merges->setMovable(true);

        verticalLayout_4->addWidget(merges);

        stack->addWidget(mergesPage);

        horizontalLayout_5->addWidget(stack);

        gbDragAndDrop = new QGroupBox(overlordWidget);
        gbDragAndDrop->setObjectName("gbDragAndDrop");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(gbDragAndDrop->sizePolicy().hasHeightForWidth());
        gbDragAndDrop->setSizePolicy(sizePolicy);
        verticalLayout_10 = new QVBoxLayout(gbDragAndDrop);
        verticalLayout_10->setObjectName("verticalLayout_10");
        wDNDFilesAllCurrent = new QWidget(gbDragAndDrop);
        wDNDFilesAllCurrent->setObjectName("wDNDFilesAllCurrent");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(wDNDFilesAllCurrent->sizePolicy().hasHeightForWidth());
        wDNDFilesAllCurrent->setSizePolicy(sizePolicy1);
        wDNDFilesAllCurrent->setAcceptDrops(true);
        verticalLayout_5 = new QVBoxLayout(wDNDFilesAllCurrent);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(-1, 0, -1, 0);
        verticalSpacer_4 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_4);

        lDNDFilesAllCurrent = new QLabel(wDNDFilesAllCurrent);
        lDNDFilesAllCurrent->setObjectName("lDNDFilesAllCurrent");
        lDNDFilesAllCurrent->setMinimumSize(QSize(48, 48));
        lDNDFilesAllCurrent->setMaximumSize(QSize(48, 48));
        lDNDFilesAllCurrent->setLineWidth(-1);
        lDNDFilesAllCurrent->setText(QString::fromUtf8(""));
        lDNDFilesAllCurrent->setPixmap(QPixmap(QString::fromUtf8(":/icons/mkvtoolnix-gui/oxygen/tab-new.svg")));
        lDNDFilesAllCurrent->setScaledContents(true);

        verticalLayout_5->addWidget(lDNDFilesAllCurrent);

        verticalSpacer_5 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_5);


        verticalLayout_10->addWidget(wDNDFilesAllCurrent);

        line = new QFrame(gbDragAndDrop);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_10->addWidget(line);

        wDNDFilesAllOneNew = new QWidget(gbDragAndDrop);
        wDNDFilesAllOneNew->setObjectName("wDNDFilesAllOneNew");
        wDNDFilesAllOneNew->setAcceptDrops(true);
        verticalLayout_6 = new QVBoxLayout(wDNDFilesAllOneNew);
        verticalLayout_6->setObjectName("verticalLayout_6");
        verticalLayout_6->setContentsMargins(-1, 0, -1, 0);
        verticalSpacer_6 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_6->addItem(verticalSpacer_6);

        lDNDFilesAllOneNew = new QLabel(wDNDFilesAllOneNew);
        lDNDFilesAllOneNew->setObjectName("lDNDFilesAllOneNew");
        lDNDFilesAllOneNew->setMinimumSize(QSize(48, 48));
        lDNDFilesAllOneNew->setMaximumSize(QSize(48, 48));
        lDNDFilesAllOneNew->setText(QString::fromUtf8(""));
        lDNDFilesAllOneNew->setPixmap(QPixmap(QString::fromUtf8(":/icons/mkvtoolnix-gui/oxygen/tab-new-background.svg")));
        lDNDFilesAllOneNew->setScaledContents(true);

        verticalLayout_6->addWidget(lDNDFilesAllOneNew);

        verticalSpacer_7 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_6->addItem(verticalSpacer_7);


        verticalLayout_10->addWidget(wDNDFilesAllOneNew);

        line_2 = new QFrame(gbDragAndDrop);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_10->addWidget(line_2);

        wDNDFilesOneNewPerFile = new QWidget(gbDragAndDrop);
        wDNDFilesOneNewPerFile->setObjectName("wDNDFilesOneNewPerFile");
        wDNDFilesOneNewPerFile->setAcceptDrops(true);
        verticalLayout_7 = new QVBoxLayout(wDNDFilesOneNewPerFile);
        verticalLayout_7->setObjectName("verticalLayout_7");
        verticalLayout_7->setContentsMargins(-1, 0, -1, 0);
        verticalSpacer_8 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_7->addItem(verticalSpacer_8);

        lDNDFilesOneNewPerFile = new QLabel(wDNDFilesOneNewPerFile);
        lDNDFilesOneNewPerFile->setObjectName("lDNDFilesOneNewPerFile");
        lDNDFilesOneNewPerFile->setMinimumSize(QSize(48, 48));
        lDNDFilesOneNewPerFile->setMaximumSize(QSize(48, 48));
        lDNDFilesOneNewPerFile->setText(QString::fromUtf8(""));
        lDNDFilesOneNewPerFile->setPixmap(QPixmap(QString::fromUtf8(":/icons/mkvtoolnix-gui/oxygen/tab-duplicate.svg")));
        lDNDFilesOneNewPerFile->setScaledContents(true);

        verticalLayout_7->addWidget(lDNDFilesOneNewPerFile);

        verticalSpacer_9 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_7->addItem(verticalSpacer_9);


        verticalLayout_10->addWidget(wDNDFilesOneNewPerFile);

        line_3 = new QFrame(gbDragAndDrop);
        line_3->setObjectName("line_3");
        line_3->setFrameShape(QFrame::Shape::HLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_10->addWidget(line_3);

        wDNDAttachmentsCover = new QWidget(gbDragAndDrop);
        wDNDAttachmentsCover->setObjectName("wDNDAttachmentsCover");
        wDNDAttachmentsCover->setAcceptDrops(true);
        verticalLayout_8 = new QVBoxLayout(wDNDAttachmentsCover);
        verticalLayout_8->setObjectName("verticalLayout_8");
        verticalLayout_8->setContentsMargins(-1, 0, -1, 0);
        verticalSpacer_10 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_8->addItem(verticalSpacer_10);

        lDNDAttachmentsCover = new QLabel(wDNDAttachmentsCover);
        lDNDAttachmentsCover->setObjectName("lDNDAttachmentsCover");
        lDNDAttachmentsCover->setMinimumSize(QSize(48, 48));
        lDNDAttachmentsCover->setMaximumSize(QSize(48, 48));
        lDNDAttachmentsCover->setText(QString::fromUtf8(""));
        lDNDAttachmentsCover->setPixmap(QPixmap(QString::fromUtf8(":/icons/mkvtoolnix-gui/oxygen/view-preview.svg")));
        lDNDAttachmentsCover->setScaledContents(true);

        verticalLayout_8->addWidget(lDNDAttachmentsCover);

        verticalSpacer_11 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_8->addItem(verticalSpacer_11);


        verticalLayout_10->addWidget(wDNDAttachmentsCover);

        line_4 = new QFrame(gbDragAndDrop);
        line_4->setObjectName("line_4");
        line_4->setFrameShape(QFrame::Shape::HLine);
        line_4->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_10->addWidget(line_4);

        wDNDAttachments = new QWidget(gbDragAndDrop);
        wDNDAttachments->setObjectName("wDNDAttachments");
        wDNDAttachments->setAcceptDrops(true);
        verticalLayout_9 = new QVBoxLayout(wDNDAttachments);
        verticalLayout_9->setObjectName("verticalLayout_9");
        verticalLayout_9->setContentsMargins(-1, 0, -1, 0);
        verticalSpacer_12 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_9->addItem(verticalSpacer_12);

        lDNDAttachments = new QLabel(wDNDAttachments);
        lDNDAttachments->setObjectName("lDNDAttachments");
        lDNDAttachments->setMinimumSize(QSize(48, 48));
        lDNDAttachments->setMaximumSize(QSize(48, 48));
        lDNDAttachments->setText(QString::fromUtf8(""));
        lDNDAttachments->setPixmap(QPixmap(QString::fromUtf8(":/icons/mkvtoolnix-gui/oxygen/mail-attachment.svg")));
        lDNDAttachments->setScaledContents(true);

        verticalLayout_9->addWidget(lDNDAttachments);

        verticalSpacer_13 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_9->addItem(verticalSpacer_13);


        verticalLayout_10->addWidget(wDNDAttachments);


        horizontalLayout_5->addWidget(gbDragAndDrop);


        verticalLayout_3->addWidget(overlordWidget);


        retranslateUi(mtx__gui__Merge__Tool);

        stack->setCurrentIndex(0);
        merges->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(mtx__gui__Merge__Tool);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__Merge__Tool)
    {
        noFileOpenedLabel->setText(QTR("No multiplex job has been opened yet.", nullptr));
        howToOpenLabel->setText(QTR("Create a new one or open an existing one via the \"multiplexer\" menu, the buttons below or drag & drop one here.", nullptr));
        label->setText(QTR("You can also drag & drop media files here.", nullptr));
        newFileButton->setText(QTR("&New", nullptr));
        openFileButton->setText(QTR("&Open settings", nullptr));
        gbDragAndDrop->setTitle(QTR("D&&D", nullptr));
        (void)mtx__gui__Merge__Tool;
    } // retranslateUi

};

} // namespace Merge
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Merge {
namespace Ui {
    class Tool: public Ui_Tool {};
} // namespace Ui
} // namespace Merge
} // namespace gui
} // namespace mtx

#endif // TOOL_H
